"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict


async def create_multiple(
    hub, ctx, configuration_set_name: str, tracking_options: Dict
) -> Dict:
    r"""
    **Autogenerated function**

    Creates an association between a configuration set and a custom domain for open and click event tracking.  By default, images and links used for tracking open and click events are hosted on domains operated by Amazon SES. You can configure a subdomain of your own to handle these events. For information about using custom domains, see the Amazon SES Developer Guide.

    Args:
        configuration_set_name(str): The name of the configuration set that the tracking options should be associated with.
        tracking_options(Dict): A domain that is used to redirect email recipients to an Amazon SES-operated domain. This domain captures open and click events generated by Amazon SES emails. For more information, see Configuring Custom Domains to Handle Open and Click Tracking in the Amazon SES Developer Guide.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.ses.configuration_set_.tracking_option.create_multiple(
                ctx, configuration_set_name=value, tracking_options=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.ses.configuration_set_.tracking_option.create_multiple configuration_set_name=value, tracking_options=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="ses",
        operation="create_configuration_set_tracking_options",
        op_kwargs={
            "ConfigurationSetName": configuration_set_name,
            "TrackingOptions": tracking_options,
        },
    )


async def delete_multiple(hub, ctx, configuration_set_name: str) -> Dict:
    r"""
    **Autogenerated function**

    Deletes an association between a configuration set and a custom domain for open and click event tracking. By default, images and links used for tracking open and click events are hosted on domains operated by Amazon SES. You can configure a subdomain of your own to handle these events. For information about using custom domains, see the Amazon SES Developer Guide.  Deleting this kind of association will result in emails sent using the specified configuration set to capture open and click events using the standard, Amazon SES-operated domains.

    Args:
        configuration_set_name(str): The name of the configuration set from which you want to delete the tracking options.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.ses.configuration_set_.tracking_option.delete_multiple(
                ctx, configuration_set_name=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.ses.configuration_set_.tracking_option.delete_multiple configuration_set_name=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="ses",
        operation="delete_configuration_set_tracking_options",
        op_kwargs={"ConfigurationSetName": configuration_set_name},
    )


async def update_multiple(
    hub, ctx, configuration_set_name: str, tracking_options: Dict
) -> Dict:
    r"""
    **Autogenerated function**

    Modifies an association between a configuration set and a custom domain for open and click event tracking.  By default, images and links used for tracking open and click events are hosted on domains operated by Amazon SES. You can configure a subdomain of your own to handle these events. For information about using custom domains, see the Amazon SES Developer Guide.

    Args:
        configuration_set_name(str): The name of the configuration set for which you want to update the custom tracking domain.
        tracking_options(Dict): A domain that is used to redirect email recipients to an Amazon SES-operated domain. This domain captures open and click events generated by Amazon SES emails. For more information, see Configuring Custom Domains to Handle Open and Click Tracking in the Amazon SES Developer Guide.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.ses.configuration_set_.tracking_option.update_multiple(
                ctx, configuration_set_name=value, tracking_options=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.ses.configuration_set_.tracking_option.update_multiple configuration_set_name=value, tracking_options=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="ses",
        operation="update_configuration_set_tracking_options",
        op_kwargs={
            "ConfigurationSetName": configuration_set_name,
            "TrackingOptions": tracking_options,
        },
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict


async def deregister(hub, ctx, admin_account_id: str = None) -> Dict:
    r"""
    **Autogenerated function**

    Removes the specified member account as a delegated administrator for Audit Manager.   When you remove a delegated administrator from your Audit Manager settings, or when you deregister a delegated administrator from Organizations, you continue to have access to the evidence that you previously collected under that account. However, Audit Manager will stop collecting and attaching evidence to that delegated administrator account moving forward.

    Args:
        admin_account_id(str, optional):  The identifier for the specified administrator account. . Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.auditmanager.organization_admin_account.deregister(ctx)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.auditmanager.organization_admin_account.deregister
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="auditmanager",
        operation="deregister_organization_admin_account",
        op_kwargs={"adminAccountId": admin_account_id},
    )


async def get(hub, ctx) -> Dict:
    r"""
    **Autogenerated function**

     Returns the name of the delegated Amazon Web Services administrator account for the organization.


    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.auditmanager.organization_admin_account.get(ctx)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.auditmanager.organization_admin_account.get
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="auditmanager",
        operation="get_organization_admin_account",
        op_kwargs={},
    )


async def register(hub, ctx, admin_account_id: str) -> Dict:
    r"""
    **Autogenerated function**

     Enables an account within the organization as the delegated administrator for Audit Manager.

    Args:
        admin_account_id(str):  The identifier for the specified delegated administrator account. .

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.auditmanager.organization_admin_account.register(
                ctx, admin_account_id=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.auditmanager.organization_admin_account.register admin_account_id=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="auditmanager",
        operation="register_organization_admin_account",
        op_kwargs={"adminAccountId": admin_account_id},
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict


async def get(
    hub,
    ctx,
    repository_name: str,
    after_commit_id: str,
    before_commit_id: str = None,
    next_token: str = None,
    max_results: int = None,
) -> Dict:
    r"""
    **Autogenerated function**

    Returns information about comments made on the comparison between two commits.  Reaction counts might include numbers from user identities who were deleted after the reaction was made. For a count of reactions from active identities, use GetCommentReactions.

    Args:
        repository_name(str): The name of the repository where you want to compare commits.
        before_commit_id(str, optional): To establish the directionality of the comparison, the full commit ID of the before commit. Defaults to None.
        after_commit_id(str): To establish the directionality of the comparison, the full commit ID of the after commit.
        next_token(str, optional): An enumeration token that when provided in a request, returns the next batch of the results. . Defaults to None.
        max_results(int, optional): A non-zero, non-negative integer used to limit the number of returned results. The default is 100 comments, but you can configure up to 500. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.codecommit.comment.for_.compared_commit.get(
                ctx, repository_name=value, after_commit_id=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.codecommit.comment.for_.compared_commit.get repository_name=value, after_commit_id=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="codecommit",
        operation="get_comments_for_compared_commit",
        op_kwargs={
            "repositoryName": repository_name,
            "beforeCommitId": before_commit_id,
            "afterCommitId": after_commit_id,
            "nextToken": next_token,
            "maxResults": max_results,
        },
    )


async def post(
    hub,
    ctx,
    repository_name: str,
    after_commit_id: str,
    content: str,
    before_commit_id: str = None,
    location: Dict = None,
    client_request_token: str = None,
) -> Dict:
    r"""
    **Autogenerated function**

    Posts a comment on the comparison between two commits.

    Args:
        repository_name(str): The name of the repository where you want to post a comment on the comparison between commits.
        before_commit_id(str, optional): To establish the directionality of the comparison, the full commit ID of the before commit. Required for commenting on any commit unless that commit is the initial commit. Defaults to None.
        after_commit_id(str): To establish the directionality of the comparison, the full commit ID of the after commit.
        location(Dict, optional): The location of the comparison where you want to comment. Defaults to None.
        content(str): The content of the comment you want to make.
        client_request_token(str, optional): A unique, client-generated idempotency token that, when provided in a request, ensures the request cannot be repeated with a changed parameter. If a request is received with the same parameters and a token is included, the request returns information about the initial request that used that token. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.codecommit.comment.for_.compared_commit.post(
                ctx, repository_name=value, after_commit_id=value, content=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.codecommit.comment.for_.compared_commit.post repository_name=value, after_commit_id=value, content=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="codecommit",
        operation="post_comment_for_compared_commit",
        op_kwargs={
            "repositoryName": repository_name,
            "beforeCommitId": before_commit_id,
            "afterCommitId": after_commit_id,
            "location": location,
            "content": content,
            "clientRequestToken": client_request_token,
        },
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict


async def get_all(hub, ctx, insight_arn: str) -> Dict:
    r"""
    **Autogenerated function**

    Lists the results of the Security Hub insight specified by the insight ARN.

    Args:
        insight_arn(str): The ARN of the insight for which to return results.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.securityhub.insight.result.get_all(ctx, insight_arn=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.securityhub.insight.result.get_all insight_arn=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="securityhub",
        operation="get_insight_results",
        op_kwargs={"InsightArn": insight_arn},
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict


__func_alias__ = {"list_": "list"}


async def list_(
    hub, ctx, resource_arn: str, limit: int = None, next_token: str = None
) -> Dict:
    r"""
    **Autogenerated function**

    List the tags for AWS Config resource.

    Args:
        resource_arn(str): The Amazon Resource Name (ARN) that identifies the resource for which to list the tags. Currently, the supported resources are ConfigRule, ConfigurationAggregator and AggregatorAuthorization.
        limit(int, optional): The maximum number of tags returned on each page. The limit maximum is 50. You cannot specify a number greater than 50. If you specify 0, AWS Config uses the default. . Defaults to None.
        next_token(str, optional): The nextToken string returned on a previous page that you use to get the next page of results in a paginated response. . Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.config.tags_for_resource.list(ctx, resource_arn=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.config.tags_for_resource.list resource_arn=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="config",
        operation="list_tags_for_resource",
        op_kwargs={
            "ResourceArn": resource_arn,
            "Limit": limit,
            "NextToken": next_token,
        },
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict


__virtualname__ = "for_object_lambda"


__func_alias__ = {"list_": "list"}


async def create(hub, ctx, account_id: str, name: str, configuration: Dict) -> Dict:
    r"""
    **Autogenerated function**

    Creates an Object Lambda Access Point. For more information, see Transforming objects with Object Lambda Access Points in the Amazon S3 User Guide. The following actions are related to CreateAccessPointForObjectLambda:    DeleteAccessPointForObjectLambda     GetAccessPointForObjectLambda     ListAccessPointsForObjectLambda

    Args:
        account_id(str): The account ID for owner of the specified Object Lambda Access Point.
        name(str): The name you want to assign to this Object Lambda Access Point.
        configuration(Dict): Object Lambda Access Point configuration as a JSON document.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.s3control.access_point.for_object_lambda_.create(
                ctx, account_id=value, name=value, configuration=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.s3control.access_point.for_object_lambda.create account_id=value, name=value, configuration=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="s3control",
        operation="create_access_point_for_object_lambda",
        op_kwargs={
            "AccountId": account_id,
            "Name": name,
            "Configuration": configuration,
        },
    )


async def delete(hub, ctx, account_id: str, name: str) -> None:
    r"""
    **Autogenerated function**

    Deletes the specified Object Lambda Access Point. The following actions are related to DeleteAccessPointForObjectLambda:    CreateAccessPointForObjectLambda     GetAccessPointForObjectLambda     ListAccessPointsForObjectLambda

    Args:
        account_id(str): The account ID for the account that owns the specified Object Lambda Access Point.
        name(str): The name of the access point you want to delete.
    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.s3control.access_point.for_object_lambda_.delete(
                ctx, account_id=value, name=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.s3control.access_point.for_object_lambda.delete account_id=value, name=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="s3control",
        operation="delete_access_point_for_object_lambda",
        op_kwargs={"AccountId": account_id, "Name": name},
    )


async def get(hub, ctx, account_id: str, name: str) -> Dict:
    r"""
    **Autogenerated function**

    Returns configuration information about the specified Object Lambda Access Point The following actions are related to GetAccessPointForObjectLambda:    CreateAccessPointForObjectLambda     DeleteAccessPointForObjectLambda     ListAccessPointsForObjectLambda

    Args:
        account_id(str): The account ID for the account that owns the specified Object Lambda Access Point.
        name(str): The name of the Object Lambda Access Point.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.s3control.access_point.for_object_lambda_.get(
                ctx, account_id=value, name=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.s3control.access_point.for_object_lambda.get account_id=value, name=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="s3control",
        operation="get_access_point_for_object_lambda",
        op_kwargs={"AccountId": account_id, "Name": name},
    )


async def list_(
    hub, ctx, account_id: str, next_token: str = None, max_results: int = None
) -> Dict:
    r"""
    **Autogenerated function**

    Returns a list of the access points associated with the Object Lambda Access Point. You can retrieve up to 1000 access points per call. If there are more than 1,000 access points (or the number specified in maxResults, whichever is less), the response will include a continuation token that you can use to list the additional access points. The following actions are related to ListAccessPointsForObjectLambda:    CreateAccessPointForObjectLambda     DeleteAccessPointForObjectLambda     GetAccessPointForObjectLambda

    Args:
        account_id(str): The account ID for the account that owns the specified Object Lambda Access Point.
        next_token(str, optional): If the list has more access points than can be returned in one call to this API, this field contains a continuation token that you can provide in subsequent calls to this API to retrieve additional access points. Defaults to None.
        max_results(int, optional): The maximum number of access points that you want to include in the list. If there are more than this number of access points, then the response will include a continuation token in the NextToken field that you can use to retrieve the next page of access points. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.s3control.access_point.for_object_lambda_.list(
                ctx, account_id=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.s3control.access_point.for_object_lambda.list account_id=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="s3control",
        operation="list_access_points_for_object_lambda",
        op_kwargs={
            "AccountId": account_id,
            "NextToken": next_token,
            "MaxResults": max_results,
        },
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict
from typing import List


async def create(
    hub,
    ctx,
    endpoint_name: str,
    role_arn: str,
    security_group_ids: List = None,
    subnet_id: str = None,
    public_key: str = None,
    public_keys: List = None,
    number_of_nodes: int = None,
    worker_type: str = None,
    glue_version: str = None,
    number_of_workers: int = None,
    extra_python_libs_s3_path: str = None,
    extra_jars_s3_path: str = None,
    security_configuration: str = None,
    tags: Dict = None,
    arguments: Dict = None,
) -> Dict:
    r"""
    **Autogenerated function**

    Creates a new development endpoint.

    Args:
        endpoint_name(str): The name to be assigned to the new DevEndpoint.
        role_arn(str): The IAM role for the DevEndpoint.
        security_group_ids(List, optional): Security group IDs for the security groups to be used by the new DevEndpoint. Defaults to None.
        subnet_id(str, optional): The subnet ID for the new DevEndpoint to use. Defaults to None.
        public_key(str, optional): The public key to be used by this DevEndpoint for authentication. This attribute is provided for backward compatibility because the recommended attribute to use is public keys. Defaults to None.
        public_keys(List, optional): A list of public keys to be used by the development endpoints for authentication. The use of this attribute is preferred over a single public key because the public keys allow you to have a different private key per client.  If you previously created an endpoint with a public key, you must remove that key to be able to set a list of public keys. Call the UpdateDevEndpoint API with the public key content in the deletePublicKeys attribute, and the list of new keys in the addPublicKeys attribute. . Defaults to None.
        number_of_nodes(int, optional): The number of Glue Data Processing Units (DPUs) to allocate to this DevEndpoint. Defaults to None.
        worker_type(str, optional): The type of predefined worker that is allocated to the development endpoint. Accepts a value of Standard, G.1X, or G.2X.   For the Standard worker type, each worker provides 4 vCPU, 16 GB of memory and a 50GB disk, and 2 executors per worker.   For the G.1X worker type, each worker maps to 1 DPU (4 vCPU, 16 GB of memory, 64 GB disk), and provides 1 executor per worker. We recommend this worker type for memory-intensive jobs.   For the G.2X worker type, each worker maps to 2 DPU (8 vCPU, 32 GB of memory, 128 GB disk), and provides 1 executor per worker. We recommend this worker type for memory-intensive jobs.   Known issue: when a development endpoint is created with the G.2X WorkerType configuration, the Spark drivers for the development endpoint will run on 4 vCPU, 16 GB of memory, and a 64 GB disk. . Defaults to None.
        glue_version(str, optional): Glue version determines the versions of Apache Spark and Python that Glue supports. The Python version indicates the version supported for running your ETL scripts on development endpoints.  For more information about the available Glue versions and corresponding Spark and Python versions, see Glue version in the developer guide. Development endpoints that are created without specifying a Glue version default to Glue 0.9. You can specify a version of Python support for development endpoints by using the Arguments parameter in the CreateDevEndpoint or UpdateDevEndpoint APIs. If no arguments are provided, the version defaults to Python 2. Defaults to None.
        number_of_workers(int, optional): The number of workers of a defined workerType that are allocated to the development endpoint. The maximum number of workers you can define are 299 for G.1X, and 149 for G.2X. . Defaults to None.
        extra_python_libs_s3_path(str, optional): The paths to one or more Python libraries in an Amazon S3 bucket that should be loaded in your DevEndpoint. Multiple values must be complete paths separated by a comma.  You can only use pure Python libraries with a DevEndpoint. Libraries that rely on C extensions, such as the pandas Python data analysis library, are not yet supported. . Defaults to None.
        extra_jars_s3_path(str, optional): The path to one or more Java .jar files in an S3 bucket that should be loaded in your DevEndpoint. Defaults to None.
        security_configuration(str, optional): The name of the SecurityConfiguration structure to be used with this DevEndpoint. Defaults to None.
        tags(Dict, optional): The tags to use with this DevEndpoint. You may use tags to limit access to the DevEndpoint. For more information about tags in Glue, see Amazon Web Services Tags in Glue in the developer guide. Defaults to None.
        arguments(Dict, optional): A map of arguments used to configure the DevEndpoint. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.glue.dev_endpoint.create(
                ctx, endpoint_name=value, role_arn=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.glue.dev_endpoint.create endpoint_name=value, role_arn=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="glue",
        operation="create_dev_endpoint",
        op_kwargs={
            "EndpointName": endpoint_name,
            "RoleArn": role_arn,
            "SecurityGroupIds": security_group_ids,
            "SubnetId": subnet_id,
            "PublicKey": public_key,
            "PublicKeys": public_keys,
            "NumberOfNodes": number_of_nodes,
            "WorkerType": worker_type,
            "GlueVersion": glue_version,
            "NumberOfWorkers": number_of_workers,
            "ExtraPythonLibsS3Path": extra_python_libs_s3_path,
            "ExtraJarsS3Path": extra_jars_s3_path,
            "SecurityConfiguration": security_configuration,
            "Tags": tags,
            "Arguments": arguments,
        },
    )


async def delete(hub, ctx, endpoint_name: str) -> Dict:
    r"""
    **Autogenerated function**

    Deletes a specified development endpoint.

    Args:
        endpoint_name(str): The name of the DevEndpoint.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.glue.dev_endpoint.delete(ctx, endpoint_name=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.glue.dev_endpoint.delete endpoint_name=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="glue",
        operation="delete_dev_endpoint",
        op_kwargs={"EndpointName": endpoint_name},
    )


async def get(hub, ctx, endpoint_name: str) -> Dict:
    r"""
    **Autogenerated function**

    Retrieves information about a specified development endpoint.  When you create a development endpoint in a virtual private cloud (VPC), Glue returns only a private IP address, and the public IP address field is not populated. When you create a non-VPC development endpoint, Glue returns only a public IP address.

    Args:
        endpoint_name(str): Name of the DevEndpoint to retrieve information for.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.glue.dev_endpoint.get(ctx, endpoint_name=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.glue.dev_endpoint.get endpoint_name=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="glue",
        operation="get_dev_endpoint",
        op_kwargs={"EndpointName": endpoint_name},
    )


async def get_all(hub, ctx, max_results: int = None, next_token: str = None) -> Dict:
    r"""
    **Autogenerated function**

    Retrieves all the development endpoints in this AWS account.  When you create a development endpoint in a virtual private cloud (VPC), Glue returns only a private IP address and the public IP address field is not populated. When you create a non-VPC development endpoint, Glue returns only a public IP address.

    Args:
        max_results(int, optional): The maximum size of information to return. Defaults to None.
        next_token(str, optional): A continuation token, if this is a continuation call. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.glue.dev_endpoint.get_all(ctx)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.glue.dev_endpoint.get_all
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="glue",
        operation="get_dev_endpoints",
        op_kwargs={"MaxResults": max_results, "NextToken": next_token},
    )


async def list_all(
    hub, ctx, next_token: str = None, max_results: int = None, tags: Dict = None
) -> Dict:
    r"""
    **Autogenerated function**

    Retrieves the names of all DevEndpoint resources in this Amazon Web Services account, or the resources with the specified tag. This operation allows you to see which resources are available in your account, and their names. This operation takes the optional Tags field, which you can use as a filter on the response so that tagged resources can be retrieved as a group. If you choose to use tags filtering, only resources with the tag are retrieved.

    Args:
        next_token(str, optional): A continuation token, if this is a continuation request. Defaults to None.
        max_results(int, optional): The maximum size of a list to return. Defaults to None.
        tags(Dict, optional): Specifies to return only these tagged resources. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.glue.dev_endpoint.list_all(ctx)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.glue.dev_endpoint.list_all
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="glue",
        operation="list_dev_endpoints",
        op_kwargs={"NextToken": next_token, "MaxResults": max_results, "Tags": tags},
    )


async def update(
    hub,
    ctx,
    endpoint_name: str,
    public_key: str = None,
    add_public_keys: List = None,
    delete_public_keys: List = None,
    custom_libraries: Dict = None,
    update_etl_libraries: bool = None,
    delete_arguments: List = None,
    add_arguments: Dict = None,
) -> Dict:
    r"""
    **Autogenerated function**

    Updates a specified development endpoint.

    Args:
        endpoint_name(str): The name of the DevEndpoint to be updated.
        public_key(str, optional): The public key for the DevEndpoint to use. Defaults to None.
        add_public_keys(List, optional): The list of public keys for the DevEndpoint to use. Defaults to None.
        delete_public_keys(List, optional): The list of public keys to be deleted from the DevEndpoint. Defaults to None.
        custom_libraries(Dict, optional): Custom Python or Java libraries to be loaded in the DevEndpoint. Defaults to None.
        update_etl_libraries(bool, optional):  True if the list of custom libraries to be loaded in the development endpoint needs to be updated, or False if otherwise. Defaults to None.
        delete_arguments(List, optional): The list of argument keys to be deleted from the map of arguments used to configure the DevEndpoint. Defaults to None.
        add_arguments(Dict, optional): The map of arguments to add the map of arguments used to configure the DevEndpoint. Valid arguments are:    "--enable-glue-datacatalog": ""    You can specify a version of Python support for development endpoints by using the Arguments parameter in the CreateDevEndpoint or UpdateDevEndpoint APIs. If no arguments are provided, the version defaults to Python 2. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.glue.dev_endpoint.update(ctx, endpoint_name=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.glue.dev_endpoint.update endpoint_name=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="glue",
        operation="update_dev_endpoint",
        op_kwargs={
            "EndpointName": endpoint_name,
            "PublicKey": public_key,
            "AddPublicKeys": add_public_keys,
            "DeletePublicKeys": delete_public_keys,
            "CustomLibraries": custom_libraries,
            "UpdateEtlLibraries": update_etl_libraries,
            "DeleteArguments": delete_arguments,
            "AddArguments": add_arguments,
        },
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict


async def allocate(
    hub,
    ctx,
    connection_id: str,
    owner_account: str,
    new_transit_virtual_interface_allocation: Dict,
) -> Dict:
    r"""
    **Autogenerated function**

    Provisions a transit virtual interface to be owned by the specified account. Use this type of interface to connect a transit gateway to your Direct Connect gateway. The owner of a connection provisions a transit virtual interface to be owned by the specified account. After you create a transit virtual interface, it must be confirmed by the owner using ConfirmTransitVirtualInterface. Until this step has been completed, the transit virtual interface is in the requested state and is not available to handle traffic.

    Args:
        connection_id(str): The ID of the connection on which the transit virtual interface is provisioned.
        owner_account(str): The ID of the account that owns the transit virtual interface.
        new_transit_virtual_interface_allocation(Dict): Information about the transit virtual interface.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.directconnect.transit_virtual_interface.allocate(
                ctx,
                connection_id=value,
                owner_account=value,
                new_transit_virtual_interface_allocation=value,
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.directconnect.transit_virtual_interface.allocate connection_id=value, owner_account=value, new_transit_virtual_interface_allocation=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="directconnect",
        operation="allocate_transit_virtual_interface",
        op_kwargs={
            "connectionId": connection_id,
            "ownerAccount": owner_account,
            "newTransitVirtualInterfaceAllocation": new_transit_virtual_interface_allocation,
        },
    )


async def confirm(
    hub, ctx, virtual_interface_id: str, direct_connect_gateway_id: str
) -> Dict:
    r"""
    **Autogenerated function**

    Accepts ownership of a transit virtual interface created by another account.  After the owner of the transit virtual interface makes this call, the specified transit virtual interface is created and made available to handle traffic.

    Args:
        virtual_interface_id(str): The ID of the virtual interface.
        direct_connect_gateway_id(str): The ID of the Direct Connect gateway.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.directconnect.transit_virtual_interface.confirm(
                ctx, virtual_interface_id=value, direct_connect_gateway_id=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.directconnect.transit_virtual_interface.confirm virtual_interface_id=value, direct_connect_gateway_id=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="directconnect",
        operation="confirm_transit_virtual_interface",
        op_kwargs={
            "virtualInterfaceId": virtual_interface_id,
            "directConnectGatewayId": direct_connect_gateway_id,
        },
    )


async def create(
    hub, ctx, connection_id: str, new_transit_virtual_interface: Dict
) -> Dict:
    r"""
    **Autogenerated function**

    Creates a transit virtual interface. A transit virtual interface should be used to access one or more transit gateways associated with Direct Connect gateways. A transit virtual interface enables the connection of multiple VPCs attached to a transit gateway to a Direct Connect gateway.  If you associate your transit gateway with one or more Direct Connect gateways, the Autonomous System Number (ASN) used by the transit gateway and the Direct Connect gateway must be different. For example, if you use the default ASN 64512 for both your the transit gateway and Direct Connect gateway, the association request fails.  Setting the MTU of a virtual interface to 8500 (jumbo frames) can cause an update to the underlying physical connection if it wasn't updated to support jumbo frames. Updating the connection disrupts network connectivity for all virtual interfaces associated with the connection for up to 30 seconds. To check whether your connection supports jumbo frames, call DescribeConnections. To check whether your virtual interface supports jumbo frames, call DescribeVirtualInterfaces.

    Args:
        connection_id(str): The ID of the connection.
        new_transit_virtual_interface(Dict): Information about the transit virtual interface.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.directconnect.transit_virtual_interface.create(
                ctx, connection_id=value, new_transit_virtual_interface=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.directconnect.transit_virtual_interface.create connection_id=value, new_transit_virtual_interface=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="directconnect",
        operation="create_transit_virtual_interface",
        op_kwargs={
            "connectionId": connection_id,
            "newTransitVirtualInterface": new_transit_virtual_interface,
        },
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict


async def put(
    hub, ctx, repository_name: str, image_tag_mutability: str, registry_id: str = None
) -> Dict:
    r"""
    **Autogenerated function**

    Updates the image tag mutability settings for the specified repository. For more information, see Image Tag Mutability in the Amazon Elastic Container Registry User Guide.

    Args:
        registry_id(str, optional): The AWS account ID associated with the registry that contains the repository in which to update the image tag mutability settings. If you do not specify a registry, the default registry is assumed. Defaults to None.
        repository_name(str): The name of the repository in which to update the image tag mutability settings.
        image_tag_mutability(str): The tag mutability setting for the repository. If MUTABLE is specified, image tags can be overwritten. If IMMUTABLE is specified, all image tags within the repository will be immutable which will prevent them from being overwritten.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.ecr.image.tag_mutability.put(
                ctx, repository_name=value, image_tag_mutability=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.ecr.image.tag_mutability.put repository_name=value, image_tag_mutability=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="ecr",
        operation="put_image_tag_mutability",
        op_kwargs={
            "registryId": registry_id,
            "repositoryName": repository_name,
            "imageTagMutability": image_tag_mutability,
        },
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict


async def create(
    hub,
    ctx,
    name: str,
    permissions_mode: str,
    tags: Dict = None,
    deletion_protection: bool = None,
    kms_key: str = None,
) -> Dict:
    r"""
    **Autogenerated function**

    Creates a new ledger in your account in the current Region.

    Args:
        name(str): The name of the ledger that you want to create. The name must be unique among all of the ledgers in your account in the current Region. Naming constraints for ledger names are defined in Quotas in Amazon QLDB in the Amazon QLDB Developer Guide.
        tags(Dict, optional): The key-value pairs to add as tags to the ledger that you want to create. Tag keys are case sensitive. Tag values are case sensitive and can be null. Defaults to None.
        permissions_mode(str): The permissions mode to assign to the ledger that you want to create. This parameter can have one of the following values:    ALLOW_ALL: A legacy permissions mode that enables access control with API-level granularity for ledgers. This mode allows users who have the SendCommand API permission for this ledger to run all PartiQL commands (hence, ALLOW_ALL) on any tables in the specified ledger. This mode disregards any table-level or command-level IAM permissions policies that you create for the ledger.    STANDARD: (Recommended) A permissions mode that enables access control with finer granularity for ledgers, tables, and PartiQL commands. By default, this mode denies all user requests to run any PartiQL commands on any tables in this ledger. To allow PartiQL commands to run, you must create IAM permissions policies for specific table resources and PartiQL actions, in addition to the SendCommand API permission for the ledger. For information, see Getting started with the standard permissions mode in the Amazon QLDB Developer Guide.    We strongly recommend using the STANDARD permissions mode to maximize the security of your ledger data. .
        deletion_protection(bool, optional): The flag that prevents a ledger from being deleted by any user. If not provided on ledger creation, this feature is enabled (true) by default. If deletion protection is enabled, you must first disable it before you can delete the ledger. You can disable it by calling the UpdateLedger operation to set the flag to false. Defaults to None.
        kms_key(str, optional): The key in Key Management Service (KMS) to use for encryption of data at rest in the ledger. For more information, see Encryption at rest in the Amazon QLDB Developer Guide. Use one of the following options to specify this parameter:    AWS_OWNED_KMS_KEY: Use an KMS key that is owned and managed by Amazon Web Services on your behalf.    Undefined: By default, use an Amazon Web Services owned KMS key.    A valid symmetric customer managed KMS key: Use the specified KMS key in your account that you create, own, and manage. Amazon QLDB does not support asymmetric keys. For more information, see Using symmetric and asymmetric keys in the Key Management Service Developer Guide.   To specify a customer managed KMS key, you can use its key ID, Amazon Resource Name (ARN), alias name, or alias ARN. When using an alias name, prefix it with "alias/". To specify a key in a different account, you must use the key ARN or alias ARN. For example:   Key ID: 1234abcd-12ab-34cd-56ef-1234567890ab    Key ARN: arn:aws:kms:us-east-2:111122223333:key/1234abcd-12ab-34cd-56ef-1234567890ab    Alias name: alias/ExampleAlias    Alias ARN: arn:aws:kms:us-east-2:111122223333:alias/ExampleAlias    For more information, see Key identifiers (KeyId) in the Key Management Service Developer Guide. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.qldb.ledger.init.create(ctx, name=value, permissions_mode=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.qldb.ledger.init.create name=value, permissions_mode=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="qldb",
        operation="create_ledger",
        op_kwargs={
            "Name": name,
            "Tags": tags,
            "PermissionsMode": permissions_mode,
            "DeletionProtection": deletion_protection,
            "KmsKey": kms_key,
        },
    )


async def delete(hub, ctx, name: str) -> None:
    r"""
    **Autogenerated function**

    Deletes a ledger and all of its contents. This action is irreversible. If deletion protection is enabled, you must first disable it before you can delete the ledger. You can disable it by calling the UpdateLedger operation to set the flag to false.

    Args:
        name(str): The name of the ledger that you want to delete.
    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.qldb.ledger.init.delete(ctx, name=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.qldb.ledger.init.delete name=value
    """
    return await hub.tool.aws.client.exec(
        ctx, service_name="qldb", operation="delete_ledger", op_kwargs={"Name": name}
    )


async def describe(hub, ctx, name: str) -> Dict:
    r"""
    **Autogenerated function**

    Returns information about a ledger, including its state, permissions mode, encryption at rest settings, and when it was created.

    Args:
        name(str): The name of the ledger that you want to describe.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.qldb.ledger.init.describe(ctx, name=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.qldb.ledger.init.describe name=value
    """
    return await hub.tool.aws.client.exec(
        ctx, service_name="qldb", operation="describe_ledger", op_kwargs={"Name": name}
    )


async def list_all(hub, ctx, max_results: int = None, next_token: str = None) -> Dict:
    r"""
    **Autogenerated function**

    Returns an array of ledger summaries that are associated with the current account and Region. This action returns a maximum of 100 items and is paginated so that you can retrieve all the items by calling ListLedgers multiple times.

    Args:
        max_results(int, optional): The maximum number of results to return in a single ListLedgers request. (The actual number of results returned might be fewer.). Defaults to None.
        next_token(str, optional): A pagination token, indicating that you want to retrieve the next page of results. If you received a value for NextToken in the response from a previous ListLedgers call, then you should use that value as input here. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.qldb.ledger.init.list_all(ctx)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.qldb.ledger.init.list_all
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="qldb",
        operation="list_ledgers",
        op_kwargs={"MaxResults": max_results, "NextToken": next_token},
    )


async def update(
    hub, ctx, name: str, deletion_protection: bool = None, kms_key: str = None
) -> Dict:
    r"""
    **Autogenerated function**

    Updates properties on a ledger.

    Args:
        name(str): The name of the ledger.
        deletion_protection(bool, optional): The flag that prevents a ledger from being deleted by any user. If not provided on ledger creation, this feature is enabled (true) by default. If deletion protection is enabled, you must first disable it before you can delete the ledger. You can disable it by calling the UpdateLedger operation to set the flag to false. Defaults to None.
        kms_key(str, optional): The key in Key Management Service (KMS) to use for encryption of data at rest in the ledger. For more information, see Encryption at rest in the Amazon QLDB Developer Guide. Use one of the following options to specify this parameter:    AWS_OWNED_KMS_KEY: Use an KMS key that is owned and managed by Amazon Web Services on your behalf.    Undefined: Make no changes to the KMS key of the ledger.    A valid symmetric customer managed KMS key: Use the specified KMS key in your account that you create, own, and manage. Amazon QLDB does not support asymmetric keys. For more information, see Using symmetric and asymmetric keys in the Key Management Service Developer Guide.   To specify a customer managed KMS key, you can use its key ID, Amazon Resource Name (ARN), alias name, or alias ARN. When using an alias name, prefix it with "alias/". To specify a key in a different account, you must use the key ARN or alias ARN. For example:   Key ID: 1234abcd-12ab-34cd-56ef-1234567890ab    Key ARN: arn:aws:kms:us-east-2:111122223333:key/1234abcd-12ab-34cd-56ef-1234567890ab    Alias name: alias/ExampleAlias    Alias ARN: arn:aws:kms:us-east-2:111122223333:alias/ExampleAlias    For more information, see Key identifiers (KeyId) in the Key Management Service Developer Guide. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.qldb.ledger.init.update(ctx, name=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.qldb.ledger.init.update name=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="qldb",
        operation="update_ledger",
        op_kwargs={
            "Name": name,
            "DeletionProtection": deletion_protection,
            "KmsKey": kms_key,
        },
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict


async def describe_all(
    hub, ctx, instance_id: str, max_results: int = None, next_token: str = None
) -> Dict:
    r"""
    **Autogenerated function**

    All associations for the instance(s).

    Args:
        instance_id(str): The instance ID for which you want to view all associations.
        max_results(int, optional): The maximum number of items to return for this call. The call also returns a token that you can specify in a subsequent call to get the next set of results. Defaults to None.
        next_token(str, optional): The token for the next set of items to return. (You received this token from a previous call.). Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.ssm.effective.instance_association.describe_all(
                ctx, instance_id=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.ssm.effective.instance_association.describe_all instance_id=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="ssm",
        operation="describe_effective_instance_associations",
        op_kwargs={
            "InstanceId": instance_id,
            "MaxResults": max_results,
            "NextToken": next_token,
        },
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict


async def get(hub, ctx, certificate_authority_arn: str) -> Dict:
    r"""
    **Autogenerated function**

    Retrieves the certificate signing request (CSR) for your private certificate authority (CA). The CSR is created when you call the CreateCertificateAuthority action. Sign the CSR with your ACM Private CA-hosted or on-premises root or subordinate CA. Then import the signed certificate back into ACM Private CA by calling the ImportCertificateAuthorityCertificate action. The CSR is returned as a base64 PEM-encoded string.

    Args:
        certificate_authority_arn(str): The Amazon Resource Name (ARN) that was returned when you called the CreateCertificateAuthority action. This must be of the form:   arn:aws:acm-pca:region:account:certificate-authority/12345678-1234-1234-1234-123456789012  .

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.acm_pca.certificate.authority.csr.get(
                ctx, certificate_authority_arn=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.acm_pca.certificate.authority.csr.get certificate_authority_arn=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="acm-pca",
        operation="get_certificate_authority_csr",
        op_kwargs={"CertificateAuthorityArn": certificate_authority_arn},
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict


__virtualname__ = "threat_intel_set"


async def create(
    hub,
    ctx,
    detector_id: str,
    name: str,
    format_: str,
    location: str,
    activate: bool,
    client_token: str = None,
    tags: Dict = None,
) -> Dict:
    r"""
    **Autogenerated function**

    Creates a new ThreatIntelSet. ThreatIntelSets consist of known malicious IP addresses. GuardDuty generates findings based on ThreatIntelSets. Only users of the administrator account can use this operation.

    Args:
        detector_id(str): The unique ID of the detector of the GuardDuty account that you want to create a threatIntelSet for.
        name(str): A user-friendly ThreatIntelSet name displayed in all findings that are generated by activity that involves IP addresses included in this ThreatIntelSet.
        format_(str): The format of the file that contains the ThreatIntelSet.
        location(str): The URI of the file that contains the ThreatIntelSet. For example: https://s3.us-west-2.amazonaws.com/my-bucket/my-object-key.
        activate(bool): A Boolean value that indicates whether GuardDuty is to start using the uploaded ThreatIntelSet.
        client_token(str, optional): The idempotency token for the create request. Defaults to None.
        tags(Dict, optional): The tags to be added to a new threat list resource. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.guardduty.threat_intel_set_.create(
                ctx, detector_id=value, name=value, format_=value, location=value, activate=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.guardduty.threat_intel_set.create detector_id=value, name=value, format_=value, location=value, activate=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="guardduty",
        operation="create_threat_intel_set",
        op_kwargs={
            "DetectorId": detector_id,
            "Name": name,
            "Format": format_,
            "Location": location,
            "Activate": activate,
            "ClientToken": client_token,
            "Tags": tags,
        },
    )


async def delete(hub, ctx, detector_id: str, threat_intel_set_id: str) -> Dict:
    r"""
    **Autogenerated function**

    Deletes the ThreatIntelSet specified by the ThreatIntelSet ID.

    Args:
        detector_id(str): The unique ID of the detector that the threatIntelSet is associated with.
        threat_intel_set_id(str): The unique ID of the threatIntelSet that you want to delete.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.guardduty.threat_intel_set_.delete(
                ctx, detector_id=value, threat_intel_set_id=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.guardduty.threat_intel_set.delete detector_id=value, threat_intel_set_id=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="guardduty",
        operation="delete_threat_intel_set",
        op_kwargs={"DetectorId": detector_id, "ThreatIntelSetId": threat_intel_set_id},
    )


async def get(hub, ctx, detector_id: str, threat_intel_set_id: str) -> Dict:
    r"""
    **Autogenerated function**

    Retrieves the ThreatIntelSet that is specified by the ThreatIntelSet ID.

    Args:
        detector_id(str): The unique ID of the detector that the threatIntelSet is associated with.
        threat_intel_set_id(str): The unique ID of the threatIntelSet that you want to get.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.guardduty.threat_intel_set_.get(
                ctx, detector_id=value, threat_intel_set_id=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.guardduty.threat_intel_set.get detector_id=value, threat_intel_set_id=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="guardduty",
        operation="get_threat_intel_set",
        op_kwargs={"DetectorId": detector_id, "ThreatIntelSetId": threat_intel_set_id},
    )


async def list_all(
    hub, ctx, detector_id: str, max_results: int = None, next_token: str = None
) -> Dict:
    r"""
    **Autogenerated function**

    Lists the ThreatIntelSets of the GuardDuty service specified by the detector ID. If you use this operation from a member account, the ThreatIntelSets associated with the administrator account are returned.

    Args:
        detector_id(str): The unique ID of the detector that the threatIntelSet is associated with.
        max_results(int, optional): You can use this parameter to indicate the maximum number of items that you want in the response. The default value is 50. The maximum value is 50. Defaults to None.
        next_token(str, optional): You can use this parameter to paginate results in the response. Set the value of this parameter to null on your first call to the list action. For subsequent calls to the action, fill nextToken in the request with the value of NextToken from the previous response to continue listing data. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.guardduty.threat_intel_set_.list_all(ctx, detector_id=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.guardduty.threat_intel_set.list_all detector_id=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="guardduty",
        operation="list_threat_intel_sets",
        op_kwargs={
            "DetectorId": detector_id,
            "MaxResults": max_results,
            "NextToken": next_token,
        },
    )


async def update(
    hub,
    ctx,
    detector_id: str,
    threat_intel_set_id: str,
    name: str = None,
    location: str = None,
    activate: bool = None,
) -> Dict:
    r"""
    **Autogenerated function**

    Updates the ThreatIntelSet specified by the ThreatIntelSet ID.

    Args:
        detector_id(str): The detectorID that specifies the GuardDuty service whose ThreatIntelSet you want to update.
        threat_intel_set_id(str): The unique ID that specifies the ThreatIntelSet that you want to update.
        name(str, optional): The unique ID that specifies the ThreatIntelSet that you want to update. Defaults to None.
        location(str, optional): The updated URI of the file that contains the ThreateIntelSet. Defaults to None.
        activate(bool, optional): The updated Boolean value that specifies whether the ThreateIntelSet is active or not. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.guardduty.threat_intel_set_.update(
                ctx, detector_id=value, threat_intel_set_id=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.guardduty.threat_intel_set.update detector_id=value, threat_intel_set_id=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="guardduty",
        operation="update_threat_intel_set",
        op_kwargs={
            "DetectorId": detector_id,
            "ThreatIntelSetId": threat_intel_set_id,
            "Name": name,
            "Location": location,
            "Activate": activate,
        },
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict


async def get(hub, ctx, bucket: str, expected_bucket_owner: str = None) -> Dict:
    r"""
    **Autogenerated function**

    Returns the Region the bucket resides in. You set the bucket's Region using the LocationConstraint request parameter in a CreateBucket request. For more information, see CreateBucket.  To use this implementation of the operation, you must be the bucket owner. The following operations are related to GetBucketLocation:    GetObject     CreateBucket

    Args:
        bucket(str): The name of the bucket for which to get the location.
        expected_bucket_owner(str, optional): The account ID of the expected bucket owner. If the bucket is owned by a different account, the request will fail with an HTTP 403 (Access Denied) error. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.s3.bucket.location.get(ctx, bucket=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.s3.bucket.location.get bucket=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="s3",
        operation="get_bucket_location",
        op_kwargs={"Bucket": bucket, "ExpectedBucketOwner": expected_bucket_owner},
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict
from typing import List


async def get(
    hub,
    ctx,
    time_period: Dict,
    group_by: List = None,
    granularity: str = None,
    filter_: Dict = None,
    sort_by: Dict = None,
    next_page_token: str = None,
    max_results: int = None,
) -> Dict:
    r"""
    **Autogenerated function**

    Retrieves the reservation utilization for your account. Management account in an organization have access to member accounts. You can filter data by dimensions in a time period. You can use GetDimensionValues to determine the possible dimension values. Currently, you can group only by SUBSCRIPTION_ID.

    Args:
        time_period(Dict): Sets the start and end dates for retrieving RI utilization. The start date is inclusive, but the end date is exclusive. For example, if start is 2017-01-01 and end is 2017-05-01, then the cost and usage data is retrieved from 2017-01-01 up to and including 2017-04-30 but not including 2017-05-01. .
        group_by(List, optional): Groups only by SUBSCRIPTION_ID. Metadata is included. Defaults to None.
        granularity(str, optional): If GroupBy is set, Granularity can't be set. If Granularity isn't set, the response object doesn't include Granularity, either MONTHLY or DAILY. If both GroupBy and Granularity aren't set, GetReservationUtilization defaults to DAILY. The GetReservationUtilization operation supports only DAILY and MONTHLY granularities. Defaults to None.
        filter_(Dict, optional): Filters utilization data by dimensions. You can filter by the following dimensions:   AZ   CACHE_ENGINE   DEPLOYMENT_OPTION   INSTANCE_TYPE   LINKED_ACCOUNT   OPERATING_SYSTEM   PLATFORM   REGION   SERVICE   SCOPE   TENANCY    GetReservationUtilization uses the same Expression object as the other operations, but only AND is supported among each dimension, and nesting is supported up to only one level deep. If there are multiple values for a dimension, they are OR'd together. Defaults to None.
        sort_by(Dict, optional): The value by which you want to sort the data. The following values are supported for Key:    UtilizationPercentage     UtilizationPercentageInUnits     PurchasedHours     PurchasedUnits     TotalActualHours     TotalActualUnits     UnusedHours     UnusedUnits     OnDemandCostOfRIHoursUsed     NetRISavings     TotalPotentialRISavings     AmortizedUpfrontFee     AmortizedRecurringFee     TotalAmortizedFee     RICostForUnusedHours     RealizedSavings     UnrealizedSavings    Supported values for SortOrder are ASCENDING or DESCENDING. Defaults to None.
        next_page_token(str, optional): The token to retrieve the next set of results. AWS provides the token when the response from a previous call has more results than the maximum page size. Defaults to None.
        max_results(int, optional): The maximum number of objects that you returned for this request. If more objects are available, in the response, AWS provides a NextPageToken value that you can use in a subsequent call to get the next batch of objects. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.ce.reservation.utilization.get(ctx, time_period=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.ce.reservation.utilization.get time_period=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="ce",
        operation="get_reservation_utilization",
        op_kwargs={
            "TimePeriod": time_period,
            "GroupBy": group_by,
            "Granularity": granularity,
            "Filter": filter_,
            "SortBy": sort_by,
            "NextPageToken": next_page_token,
            "MaxResults": max_results,
        },
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict


async def create(
    hub,
    ctx,
    name: str,
    input_: Dict,
    format_: str = None,
    format_options: Dict = None,
    path_options: Dict = None,
    tags: Dict = None,
) -> Dict:
    r"""
    **Autogenerated function**

    Creates a new DataBrew dataset.

    Args:
        name(str): The name of the dataset to be created. Valid characters are alphanumeric (A-Z, a-z, 0-9), hyphen (-), period (.), and space.
        format_(str, optional): The file format of a dataset that is created from an Amazon S3 file or folder. Defaults to None.
        format_options(Dict, optional): Represents a set of options that define the structure of either comma-separated value (CSV), Excel, or JSON input. Defaults to None.
        input_(Dict): Represents information on how DataBrew can find data, in either the Glue Data Catalog or Amazon S3.
        path_options(Dict, optional): A set of options that defines how DataBrew interprets an Amazon S3 path of the dataset. Defaults to None.
        tags(Dict, optional): Metadata tags to apply to this dataset. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.databrew.dataset.create(ctx, name=value, input_=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.databrew.dataset.create name=value, input_=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="databrew",
        operation="create_dataset",
        op_kwargs={
            "Name": name,
            "Format": format_,
            "FormatOptions": format_options,
            "Input": input_,
            "PathOptions": path_options,
            "Tags": tags,
        },
    )


async def delete(hub, ctx, name: str) -> Dict:
    r"""
    **Autogenerated function**

    Deletes a dataset from DataBrew.

    Args:
        name(str): The name of the dataset to be deleted.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.databrew.dataset.delete(ctx, name=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.databrew.dataset.delete name=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="databrew",
        operation="delete_dataset",
        op_kwargs={"Name": name},
    )


async def describe(hub, ctx, name: str) -> Dict:
    r"""
    **Autogenerated function**

    Returns the definition of a specific DataBrew dataset.

    Args:
        name(str): The name of the dataset to be described.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.databrew.dataset.describe(ctx, name=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.databrew.dataset.describe name=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="databrew",
        operation="describe_dataset",
        op_kwargs={"Name": name},
    )


async def list_all(hub, ctx, max_results: int = None, next_token: str = None) -> Dict:
    r"""
    **Autogenerated function**

    Lists all of the DataBrew datasets.

    Args:
        max_results(int, optional): The maximum number of results to return in this request. . Defaults to None.
        next_token(str, optional): The token returned by a previous call to retrieve the next set of results. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.databrew.dataset.list_all(ctx)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.databrew.dataset.list_all
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="databrew",
        operation="list_datasets",
        op_kwargs={"MaxResults": max_results, "NextToken": next_token},
    )


async def update(
    hub,
    ctx,
    name: str,
    input_: Dict,
    format_: str = None,
    format_options: Dict = None,
    path_options: Dict = None,
) -> Dict:
    r"""
    **Autogenerated function**

    Modifies the definition of an existing DataBrew dataset.

    Args:
        name(str): The name of the dataset to be updated.
        format_(str, optional): The file format of a dataset that is created from an Amazon S3 file or folder. Defaults to None.
        format_options(Dict, optional): Represents a set of options that define the structure of either comma-separated value (CSV), Excel, or JSON input. Defaults to None.
        input_(Dict): Represents information on how DataBrew can find data, in either the Glue Data Catalog or Amazon S3.
        path_options(Dict, optional): A set of options that defines how DataBrew interprets an Amazon S3 path of the dataset. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.databrew.dataset.update(ctx, name=value, input_=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.databrew.dataset.update name=value, input_=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="databrew",
        operation="update_dataset",
        op_kwargs={
            "Name": name,
            "Format": format_,
            "FormatOptions": format_options,
            "Input": input_,
            "PathOptions": path_options,
        },
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict
from typing import List


async def describe_all(
    hub,
    ctx,
    engine_name: str,
    major_engine_version: str = None,
    filters: List = None,
    max_records: int = None,
    marker: str = None,
) -> Dict:
    r"""
    **Autogenerated function**

    Describes all available options.

    Args:
        engine_name(str): A required parameter. Options available for the given engine name are described. Valid Values:     mariadb     mysql     oracle-ee     oracle-ee-cdb     oracle-se2     oracle-se2-cdb     postgres     sqlserver-ee     sqlserver-se     sqlserver-ex     sqlserver-web   .
        major_engine_version(str, optional): If specified, filters the results to include only options for the specified major engine version. Defaults to None.
        filters(List, optional): This parameter isn't currently supported. Defaults to None.
        max_records(int, optional):  The maximum number of records to include in the response. If more records exist than the specified MaxRecords value, a pagination token called a marker is included in the response so that you can retrieve the remaining results.  Default: 100 Constraints: Minimum 20, maximum 100. Defaults to None.
        marker(str, optional): An optional pagination token provided by a previous request. If this parameter is specified, the response includes only records beyond the marker, up to the value specified by MaxRecords. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.rds.option_group.option.describe_all(ctx, engine_name=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.rds.option_group.option.describe_all engine_name=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="rds",
        operation="describe_option_group_options",
        op_kwargs={
            "EngineName": engine_name,
            "MajorEngineVersion": major_engine_version,
            "Filters": filters,
            "MaxRecords": max_records,
            "Marker": marker,
        },
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict
from typing import List


async def get(
    hub,
    ctx,
    service_name: str,
    metric_name: str,
    start_time: str,
    end_time: str,
    period: int,
    statistics: List,
) -> Dict:
    r"""
    **Autogenerated function**

    Returns the data points of a specific metric of your Amazon Lightsail container service. Metrics report the utilization of your resources. Monitor and collect metric data regularly to maintain the reliability, availability, and performance of your resources.

    Args:
        service_name(str): The name of the container service for which to get metric data.
        metric_name(str): The metric for which you want to return information. Valid container service metric names are listed below, along with the most useful statistics to include in your request, and the published unit value.    CPUUtilization - The average percentage of compute units that are currently in use across all nodes of the container service. This metric identifies the processing power required to run containers on each node of the container service. Statistics: The most useful statistics are Maximum and Average. Unit: The published unit is Percent.    MemoryUtilization - The average percentage of available memory that is currently in use across all nodes of the container service. This metric identifies the memory required to run containers on each node of the container service. Statistics: The most useful statistics are Maximum and Average. Unit: The published unit is Percent.  .
        start_time(str): The start time of the time period.
        end_time(str): The end time of the time period.
        period(int): The granularity, in seconds, of the returned data points. All container service metric data is available in 5-minute (300 seconds) granularity.
        statistics(List): The statistic for the metric. The following statistics are available:    Minimum - The lowest value observed during the specified period. Use this value to determine low volumes of activity for your application.    Maximum - The highest value observed during the specified period. Use this value to determine high volumes of activity for your application.    Sum - All values submitted for the matching metric added together. You can use this statistic to determine the total volume of a metric.    Average - The value of Sum / SampleCount during the specified period. By comparing this statistic with the Minimum and Maximum values, you can determine the full scope of a metric and how close the average use is to the Minimum and Maximum values. This comparison helps you to know when to increase or decrease your resources.    SampleCount - The count, or number, of data points used for the statistical calculation.  .

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.lightsail.container.service.metric_data.get(
                ctx,
                service_name=value,
                metric_name=value,
                start_time=value,
                end_time=value,
                period=value,
                statistics=value,
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.lightsail.container.service.metric_data.get service_name=value, metric_name=value, start_time=value, end_time=value, period=value, statistics=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="lightsail",
        operation="get_container_service_metric_data",
        op_kwargs={
            "serviceName": service_name,
            "metricName": metric_name,
            "startTime": start_time,
            "endTime": end_time,
            "period": period,
            "statistics": statistics,
        },
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict
from typing import List


async def describe_all(hub, ctx, mount_target_id: str) -> Dict:
    r"""
    **Autogenerated function**

    Returns the security groups currently in effect for a mount target. This operation requires that the network interface of the mount target has been created and the lifecycle state of the mount target is not deleted. This operation requires permissions for the following actions:    elasticfilesystem:DescribeMountTargetSecurityGroups action on the mount target's file system.     ec2:DescribeNetworkInterfaceAttribute action on the mount target's network interface.

    Args:
        mount_target_id(str): The ID of the mount target whose security groups you want to retrieve.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.efs.mount_target.security_group.describe_all(
                ctx, mount_target_id=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.efs.mount_target.security_group.describe_all mount_target_id=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="efs",
        operation="describe_mount_target_security_groups",
        op_kwargs={"MountTargetId": mount_target_id},
    )


async def modify(hub, ctx, mount_target_id: str, security_groups: List = None) -> None:
    r"""
    **Autogenerated function**

    Modifies the set of security groups in effect for a mount target. When you create a mount target, Amazon EFS also creates a new network interface. For more information, see CreateMountTarget. This operation replaces the security groups in effect for the network interface associated with a mount target, with the SecurityGroups provided in the request. This operation requires that the network interface of the mount target has been created and the lifecycle state of the mount target is not deleted.  The operation requires permissions for the following actions:    elasticfilesystem:ModifyMountTargetSecurityGroups action on the mount target's file system.     ec2:ModifyNetworkInterfaceAttribute action on the mount target's network interface.

    Args:
        mount_target_id(str): The ID of the mount target whose security groups you want to modify.
        security_groups(List, optional): An array of up to five VPC security group IDs. Defaults to None.
    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.efs.mount_target.security_group.modify(
                ctx, mount_target_id=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.efs.mount_target.security_group.modify mount_target_id=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="efs",
        operation="modify_mount_target_security_groups",
        op_kwargs={"MountTargetId": mount_target_id, "SecurityGroups": security_groups},
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict
from typing import List


async def describe_all(
    hub, ctx, tasks: List, cluster: str = None, include: List = None
) -> Dict:
    r"""
    **Autogenerated function**

    Describes a specified task or tasks.

    Args:
        cluster(str, optional): The short name or full Amazon Resource Name (ARN) of the cluster that hosts the task or tasks to describe. If you do not specify a cluster, the default cluster is assumed. This parameter is required if the task or tasks you are describing were launched in any cluster other than the default cluster. Defaults to None.
        tasks(List): A list of up to 100 task IDs or full ARN entries.
        include(List, optional): Specifies whether you want to see the resource tags for the task. If TAGS is specified, the tags are included in the response. If this field is omitted, tags are not included in the response. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.ecs.task.init.describe_all(ctx, tasks=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.ecs.task.init.describe_all tasks=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="ecs",
        operation="describe_tasks",
        op_kwargs={"cluster": cluster, "tasks": tasks, "include": include},
    )


async def list_all(
    hub,
    ctx,
    cluster: str = None,
    container_instance: str = None,
    family: str = None,
    next_token: str = None,
    max_results: int = None,
    started_by: str = None,
    service_name: str = None,
    desired_status: str = None,
    launch_type: str = None,
) -> Dict:
    r"""
    **Autogenerated function**

    Returns a list of tasks. You can filter the results by cluster, task definition family, container instance, launch type, what IAM principal started the task, or by the desired status of the task. Recently stopped tasks might appear in the returned results. Currently, stopped tasks appear in the returned results for at least one hour.

    Args:
        cluster(str, optional): The short name or full Amazon Resource Name (ARN) of the cluster to use when filtering the ListTasks results. If you do not specify a cluster, the default cluster is assumed. Defaults to None.
        container_instance(str, optional): The container instance ID or full ARN of the container instance to use when filtering the ListTasks results. Specifying a containerInstance limits the results to tasks that belong to that container instance. Defaults to None.
        family(str, optional): The name of the task definition family to use when filtering the ListTasks results. Specifying a family limits the results to tasks that belong to that family. Defaults to None.
        next_token(str, optional): The nextToken value returned from a ListTasks request indicating that more results are available to fulfill the request and further calls will be needed. If maxResults was provided, it is possible the number of results to be fewer than maxResults.  This token should be treated as an opaque identifier that is only used to retrieve the next items in a list and not for other programmatic purposes. . Defaults to None.
        max_results(int, optional): The maximum number of task results returned by ListTasks in paginated output. When this parameter is used, ListTasks only returns maxResults results in a single page along with a nextToken response element. The remaining results of the initial request can be seen by sending another ListTasks request with the returned nextToken value. This value can be between 1 and 100. If this parameter is not used, then ListTasks returns up to 100 results and a nextToken value if applicable. Defaults to None.
        started_by(str, optional): The startedBy value with which to filter the task results. Specifying a startedBy value limits the results to tasks that were started with that value. Defaults to None.
        service_name(str, optional): The name of the service to use when filtering the ListTasks results. Specifying a serviceName limits the results to tasks that belong to that service. Defaults to None.
        desired_status(str, optional): The task desired status to use when filtering the ListTasks results. Specifying a desiredStatus of STOPPED limits the results to tasks that Amazon ECS has set the desired status to STOPPED. This can be useful for debugging tasks that are not starting properly or have died or finished. The default status filter is RUNNING, which shows tasks that Amazon ECS has set the desired status to RUNNING.  Although you can filter results based on a desired status of PENDING, this does not return any results. Amazon ECS never sets the desired status of a task to that value (only a task's lastStatus may have a value of PENDING). . Defaults to None.
        launch_type(str, optional): The launch type to use when filtering the ListTasks results. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.ecs.task.init.list_all(ctx)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.ecs.task.init.list_all
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="ecs",
        operation="list_tasks",
        op_kwargs={
            "cluster": cluster,
            "containerInstance": container_instance,
            "family": family,
            "nextToken": next_token,
            "maxResults": max_results,
            "startedBy": started_by,
            "serviceName": service_name,
            "desiredStatus": desired_status,
            "launchType": launch_type,
        },
    )


async def run(
    hub,
    ctx,
    task_definition: str,
    capacity_provider_strategy: List = None,
    cluster: str = None,
    count: int = None,
    enable_ecs_managed_tags: bool = None,
    enable_execute_command: bool = None,
    group: str = None,
    launch_type: str = None,
    network_configuration: Dict = None,
    overrides: Dict = None,
    placement_constraints: List = None,
    placement_strategy: List = None,
    platform_version: str = None,
    propagate_tags: str = None,
    reference_id: str = None,
    started_by: str = None,
    tags: List = None,
) -> Dict:
    r"""
    **Autogenerated function**

    Starts a new task using the specified task definition. You can allow Amazon ECS to place tasks for you, or you can customize how Amazon ECS places tasks using placement constraints and placement strategies. For more information, see Scheduling Tasks in the Amazon Elastic Container Service Developer Guide. Alternatively, you can use StartTask to use your own scheduler or place tasks manually on specific container instances. The Amazon ECS API follows an eventual consistency model, due to the distributed nature of the system supporting the API. This means that the result of an API command you run that affects your Amazon ECS resources might not be immediately visible to all subsequent commands you run. Keep this in mind when you carry out an API command that immediately follows a previous API command. To manage eventual consistency, you can do the following:   Confirm the state of the resource before you run a command to modify it. Run the DescribeTasks command using an exponential backoff algorithm to ensure that you allow enough time for the previous command to propagate through the system. To do this, run the DescribeTasks command repeatedly, starting with a couple of seconds of wait time and increasing gradually up to five minutes of wait time.   Add wait time between subsequent commands, even if the DescribeTasks command returns an accurate response. Apply an exponential backoff algorithm starting with a couple of seconds of wait time, and increase gradually up to about five minutes of wait time.

    Args:
        capacity_provider_strategy(List, optional): The capacity provider strategy to use for the task. If a capacityProviderStrategy is specified, the launchType parameter must be omitted. If no capacityProviderStrategy or launchType is specified, the defaultCapacityProviderStrategy for the cluster is used. When you use cluster auto scaling, you must specify capacityProviderStrategy and not launchType. . Defaults to None.
        cluster(str, optional): The short name or full Amazon Resource Name (ARN) of the cluster on which to run your task. If you do not specify a cluster, the default cluster is assumed. Defaults to None.
        count(int, optional): The number of instantiations of the specified task to place on your cluster. You can specify up to 10 tasks per call. Defaults to None.
        enable_ecs_managed_tags(bool, optional): Specifies whether to enable Amazon ECS managed tags for the task. For more information, see Tagging Your Amazon ECS Resources in the Amazon Elastic Container Service Developer Guide. Defaults to None.
        enable_execute_command(bool, optional): Whether or not to enable the execute command functionality for the containers in this task. If true, this enables execute command functionality on all containers in the task. Defaults to None.
        group(str, optional): The name of the task group to associate with the task. The default value is the family name of the task definition (for example, family:my-family-name). Defaults to None.
        launch_type(str, optional): The infrastructure on which to run your standalone task. For more information, see Amazon ECS launch types in the Amazon Elastic Container Service Developer Guide. The FARGATE launch type runs your tasks on Fargate On-Demand infrastructure.  Fargate Spot infrastructure is available for use but a capacity provider strategy must be used. For more information, see Fargate capacity providers in the Amazon ECS User Guide for Fargate.  The EC2 launch type runs your tasks on Amazon EC2 instances registered to your cluster. The EXTERNAL launch type runs your tasks on your on-premise server or virtual machine (VM) capacity registered to your cluster. A task can use either a launch type or a capacity provider strategy. If a launchType is specified, the capacityProviderStrategy parameter must be omitted. When you use cluster auto scaling, you must specify capacityProviderStrategy and not launchType. . Defaults to None.
        network_configuration(Dict, optional): The network configuration for the task. This parameter is required for task definitions that use the awsvpc network mode to receive their own elastic network interface, and it is not supported for other network modes. For more information, see Task Networking in the Amazon Elastic Container Service Developer Guide. Defaults to None.
        overrides(Dict, optional): A list of container overrides in JSON format that specify the name of a container in the specified task definition and the overrides it should receive. You can override the default command for a container (that is specified in the task definition or Docker image) with a command override. You can also override existing environment variables (that are specified in the task definition or Docker image) on a container or add new environment variables to it with an environment override.  A total of 8192 characters are allowed for overrides. This limit includes the JSON formatting characters of the override structure. . Defaults to None.
        placement_constraints(List, optional): An array of placement constraint objects to use for the task. You can specify up to 10 constraints per task (including constraints in the task definition and those specified at runtime). Defaults to None.
        placement_strategy(List, optional): The placement strategy objects to use for the task. You can specify a maximum of five strategy rules per task. Defaults to None.
        platform_version(str, optional): The platform version the task should run. A platform version is only specified for tasks using the Fargate launch type. If one is not specified, the LATEST platform version is used by default. For more information, see Fargate Platform Versions in the Amazon Elastic Container Service Developer Guide. Defaults to None.
        propagate_tags(str, optional): Specifies whether to propagate the tags from the task definition to the task. If no value is specified, the tags are not propagated. Tags can only be propagated to the task during task creation. To add tags to a task after task creation, use the TagResource API action.  An error will be received if you specify the SERVICE option when running a task. . Defaults to None.
        reference_id(str, optional): The reference ID to use for the task. Defaults to None.
        started_by(str, optional): An optional tag specified when a task is started. For example, if you automatically trigger a task to run a batch process job, you could apply a unique identifier for that job to your task with the startedBy parameter. You can then identify which tasks belong to that job by filtering the results of a ListTasks call with the startedBy value. Up to 36 letters (uppercase and lowercase), numbers, hyphens, and underscores are allowed. If a task is started by an Amazon ECS service, then the startedBy parameter contains the deployment ID of the service that starts it. Defaults to None.
        tags(List, optional): The metadata that you apply to the task to help you categorize and organize them. Each tag consists of a key and an optional value, both of which you define. The following basic restrictions apply to tags:   Maximum number of tags per resource - 50   For each resource, each tag key must be unique, and each tag key can have only one value.   Maximum key length - 128 Unicode characters in UTF-8   Maximum value length - 256 Unicode characters in UTF-8   If your tagging schema is used across multiple services and resources, remember that other services may have restrictions on allowed characters. Generally allowed characters are: letters, numbers, and spaces representable in UTF-8, and the following characters: + - = . _ : / @.   Tag keys and values are case-sensitive.   Do not use aws:, AWS:, or any upper or lowercase combination of such as a prefix for either keys or values as it is reserved for Amazon Web Services use. You cannot edit or delete tag keys or values with this prefix. Tags with this prefix do not count against your tags per resource limit.  . Defaults to None.
        task_definition(str): The family and revision (family:revision) or full ARN of the task definition to run. If a revision is not specified, the latest ACTIVE revision is used.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.ecs.task.init.run(ctx, task_definition=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.ecs.task.init.run task_definition=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="ecs",
        operation="run_task",
        op_kwargs={
            "capacityProviderStrategy": capacity_provider_strategy,
            "cluster": cluster,
            "count": count,
            "enableECSManagedTags": enable_ecs_managed_tags,
            "enableExecuteCommand": enable_execute_command,
            "group": group,
            "launchType": launch_type,
            "networkConfiguration": network_configuration,
            "overrides": overrides,
            "placementConstraints": placement_constraints,
            "placementStrategy": placement_strategy,
            "platformVersion": platform_version,
            "propagateTags": propagate_tags,
            "referenceId": reference_id,
            "startedBy": started_by,
            "tags": tags,
            "taskDefinition": task_definition,
        },
    )


async def start(
    hub,
    ctx,
    container_instances: List,
    task_definition: str,
    cluster: str = None,
    enable_ecs_managed_tags: bool = None,
    enable_execute_command: bool = None,
    group: str = None,
    network_configuration: Dict = None,
    overrides: Dict = None,
    propagate_tags: str = None,
    reference_id: str = None,
    started_by: str = None,
    tags: List = None,
) -> Dict:
    r"""
    **Autogenerated function**

    Starts a new task from the specified task definition on the specified container instance or instances. Alternatively, you can use RunTask to place tasks for you. For more information, see Scheduling Tasks in the Amazon Elastic Container Service Developer Guide.

    Args:
        cluster(str, optional): The short name or full Amazon Resource Name (ARN) of the cluster on which to start your task. If you do not specify a cluster, the default cluster is assumed. Defaults to None.
        container_instances(List): The container instance IDs or full ARN entries for the container instances on which you would like to place your task. You can specify up to 10 container instances.
        enable_ecs_managed_tags(bool, optional): Specifies whether to enable Amazon ECS managed tags for the task. For more information, see Tagging Your Amazon ECS Resources in the Amazon Elastic Container Service Developer Guide. Defaults to None.
        enable_execute_command(bool, optional): Whether or not the execute command functionality is enabled for the task. If true, this enables execute command functionality on all containers in the task. Defaults to None.
        group(str, optional): The name of the task group to associate with the task. The default value is the family name of the task definition (for example, family:my-family-name). Defaults to None.
        network_configuration(Dict, optional): The VPC subnet and security group configuration for tasks that receive their own elastic network interface by using the awsvpc networking mode. Defaults to None.
        overrides(Dict, optional): A list of container overrides in JSON format that specify the name of a container in the specified task definition and the overrides it should receive. You can override the default command for a container (that is specified in the task definition or Docker image) with a command override. You can also override existing environment variables (that are specified in the task definition or Docker image) on a container or add new environment variables to it with an environment override.  A total of 8192 characters are allowed for overrides. This limit includes the JSON formatting characters of the override structure. . Defaults to None.
        propagate_tags(str, optional): Specifies whether to propagate the tags from the task definition or the service to the task. If no value is specified, the tags are not propagated. Defaults to None.
        reference_id(str, optional): The reference ID to use for the task. Defaults to None.
        started_by(str, optional): An optional tag specified when a task is started. For example, if you automatically trigger a task to run a batch process job, you could apply a unique identifier for that job to your task with the startedBy parameter. You can then identify which tasks belong to that job by filtering the results of a ListTasks call with the startedBy value. Up to 36 letters (uppercase and lowercase), numbers, hyphens, and underscores are allowed. If a task is started by an Amazon ECS service, then the startedBy parameter contains the deployment ID of the service that starts it. Defaults to None.
        tags(List, optional): The metadata that you apply to the task to help you categorize and organize them. Each tag consists of a key and an optional value, both of which you define. The following basic restrictions apply to tags:   Maximum number of tags per resource - 50   For each resource, each tag key must be unique, and each tag key can have only one value.   Maximum key length - 128 Unicode characters in UTF-8   Maximum value length - 256 Unicode characters in UTF-8   If your tagging schema is used across multiple services and resources, remember that other services may have restrictions on allowed characters. Generally allowed characters are: letters, numbers, and spaces representable in UTF-8, and the following characters: + - = . _ : / @.   Tag keys and values are case-sensitive.   Do not use aws:, AWS:, or any upper or lowercase combination of such as a prefix for either keys or values as it is reserved for Amazon Web Services use. You cannot edit or delete tag keys or values with this prefix. Tags with this prefix do not count against your tags per resource limit.  . Defaults to None.
        task_definition(str): The family and revision (family:revision) or full ARN of the task definition to start. If a revision is not specified, the latest ACTIVE revision is used.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.ecs.task.init.start(
                ctx, container_instances=value, task_definition=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.ecs.task.init.start container_instances=value, task_definition=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="ecs",
        operation="start_task",
        op_kwargs={
            "cluster": cluster,
            "containerInstances": container_instances,
            "enableECSManagedTags": enable_ecs_managed_tags,
            "enableExecuteCommand": enable_execute_command,
            "group": group,
            "networkConfiguration": network_configuration,
            "overrides": overrides,
            "propagateTags": propagate_tags,
            "referenceId": reference_id,
            "startedBy": started_by,
            "tags": tags,
            "taskDefinition": task_definition,
        },
    )


async def stop(hub, ctx, task: str, cluster: str = None, reason: str = None) -> Dict:
    r"""
    **Autogenerated function**

    Stops a running task. Any tags associated with the task will be deleted. When StopTask is called on a task, the equivalent of docker stop is issued to the containers running in the task. This results in a SIGTERM value and a default 30-second timeout, after which the SIGKILL value is sent and the containers are forcibly stopped. If the container handles the SIGTERM value gracefully and exits within 30 seconds from receiving it, no SIGKILL value is sent.  The default 30-second timeout can be configured on the Amazon ECS container agent with the ECS_CONTAINER_STOP_TIMEOUT variable. For more information, see Amazon ECS Container Agent Configuration in the Amazon Elastic Container Service Developer Guide.

    Args:
        cluster(str, optional): The short name or full Amazon Resource Name (ARN) of the cluster that hosts the task to stop. If you do not specify a cluster, the default cluster is assumed. Defaults to None.
        task(str): The task ID or full Amazon Resource Name (ARN) of the task to stop.
        reason(str, optional): An optional message specified when a task is stopped. For example, if you are using a custom scheduler, you can use this parameter to specify the reason for stopping the task here, and the message appears in subsequent DescribeTasks API operations on this task. Up to 255 characters are allowed in this message. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.ecs.task.init.stop(ctx, task=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.ecs.task.init.stop task=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="ecs",
        operation="stop_task",
        op_kwargs={"cluster": cluster, "task": task, "reason": reason},
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict


async def list_all(
    hub,
    ctx,
    assessment_run_arn: str,
    filter_: Dict = None,
    next_token: str = None,
    max_results: int = None,
) -> Dict:
    r"""
    **Autogenerated function**

    Lists the agents of the assessment runs that are specified by the ARNs of the assessment runs.

    Args:
        assessment_run_arn(str): The ARN that specifies the assessment run whose agents you want to list.
        filter_(Dict, optional): You can use this parameter to specify a subset of data to be included in the action's response. For a record to match a filter, all specified filter attributes must match. When multiple values are specified for a filter attribute, any of the values can match. Defaults to None.
        next_token(str, optional): You can use this parameter when paginating results. Set the value of this parameter to null on your first call to the ListAssessmentRunAgents action. Subsequent calls to the action fill nextToken in the request with the value of NextToken from the previous response to continue listing data. Defaults to None.
        max_results(int, optional): You can use this parameter to indicate the maximum number of items that you want in the response. The default value is 10. The maximum value is 500. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.inspector.assessment.run.agent.list_all(
                ctx, assessment_run_arn=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.inspector.assessment.run.agent.list_all assessment_run_arn=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="inspector",
        operation="list_assessment_run_agents",
        op_kwargs={
            "assessmentRunArn": assessment_run_arn,
            "filter": filter_,
            "nextToken": next_token,
            "maxResults": max_results,
        },
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict
from typing import List


async def batch(
    hub, ctx, request_items: Dict, return_consumed_capacity: str = None
) -> Dict:
    r"""
    **Autogenerated function**

    The BatchGetItem operation returns the attributes of one or more items from one or more tables. You identify requested items by primary key. A single operation can retrieve up to 16 MB of data, which can contain as many as 100 items. BatchGetItem returns a partial result if the response size limit is exceeded, the table's provisioned throughput is exceeded, or an internal processing failure occurs. If a partial result is returned, the operation returns a value for UnprocessedKeys. You can use this value to retry the operation starting with the next item to get.  If you request more than 100 items, BatchGetItem returns a ValidationException with the message "Too many items requested for the BatchGetItem call."  For example, if you ask to retrieve 100 items, but each individual item is 300 KB in size, the system returns 52 items (so as not to exceed the 16 MB limit). It also returns an appropriate UnprocessedKeys value so you can get the next page of results. If desired, your application can include its own logic to assemble the pages of results into one dataset. If none of the items can be processed due to insufficient provisioned throughput on all of the tables in the request, then BatchGetItem returns a ProvisionedThroughputExceededException. If at least one of the items is successfully processed, then BatchGetItem completes successfully, while returning the keys of the unread items in UnprocessedKeys.  If DynamoDB returns any unprocessed items, you should retry the batch operation on those items. However, we strongly recommend that you use an exponential backoff algorithm. If you retry the batch operation immediately, the underlying read or write requests can still fail due to throttling on the individual tables. If you delay the batch operation using exponential backoff, the individual requests in the batch are much more likely to succeed. For more information, see Batch Operations and Error Handling in the Amazon DynamoDB Developer Guide.  By default, BatchGetItem performs eventually consistent reads on every table in the request. If you want strongly consistent reads instead, you can set ConsistentRead to true for any or all tables. In order to minimize response latency, BatchGetItem retrieves items in parallel. When designing your application, keep in mind that DynamoDB does not return items in any particular order. To help parse the response by item, include the primary key values for the items in your request in the ProjectionExpression parameter. If a requested item does not exist, it is not returned in the result. Requests for nonexistent items consume the minimum read capacity units according to the type of read. For more information, see Working with Tables in the Amazon DynamoDB Developer Guide.

    Args:
        request_items(Dict): A map of one or more table names and, for each table, a map that describes one or more items to retrieve from that table. Each table name can be used only once per BatchGetItem request. Each element in the map of items to retrieve consists of the following:    ConsistentRead - If true, a strongly consistent read is used; if false (the default), an eventually consistent read is used.    ExpressionAttributeNames - One or more substitution tokens for attribute names in the ProjectionExpression parameter. The following are some use cases for using ExpressionAttributeNames:   To access an attribute whose name conflicts with a DynamoDB reserved word.   To create a placeholder for repeating occurrences of an attribute name in an expression.   To prevent special characters in an attribute name from being misinterpreted in an expression.   Use the # character in an expression to dereference an attribute name. For example, consider the following attribute name:    Percentile    The name of this attribute conflicts with a reserved word, so it cannot be used directly in an expression. (For the complete list of reserved words, see Reserved Words in the Amazon DynamoDB Developer Guide). To work around this, you could specify the following for ExpressionAttributeNames:    {"#P":"Percentile"}    You could then use this substitution in an expression, as in this example:    #P = :val     Tokens that begin with the : character are expression attribute values, which are placeholders for the actual value at runtime.  For more information about expression attribute names, see Accessing Item Attributes in the Amazon DynamoDB Developer Guide.    Keys - An array of primary key attribute values that define specific items in the table. For each primary key, you must provide all of the key attributes. For example, with a simple primary key, you only need to provide the partition key value. For a composite key, you must provide both the partition key value and the sort key value.    ProjectionExpression - A string that identifies one or more attributes to retrieve from the table. These attributes can include scalars, sets, or elements of a JSON document. The attributes in the expression must be separated by commas. If no attribute names are specified, then all attributes are returned. If any of the requested attributes are not found, they do not appear in the result. For more information, see Accessing Item Attributes in the Amazon DynamoDB Developer Guide.    AttributesToGet - This is a legacy parameter. Use ProjectionExpression instead. For more information, see AttributesToGet in the Amazon DynamoDB Developer Guide.   .
        return_consumed_capacity(str, optional): Determines the level of detail about provisioned throughput consumption that is returned in the response:    INDEXES - The response includes the aggregate ConsumedCapacity for the operation, together with ConsumedCapacity for each table and secondary index that was accessed. Note that some operations, such as GetItem and BatchGetItem, do not access any indexes at all. In these cases, specifying INDEXES will only return ConsumedCapacity information for table(s).    TOTAL - The response includes only the aggregate ConsumedCapacity for the operation.    NONE - No ConsumedCapacity details are included in the response.  . Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.dynamodb.get_item.batch(ctx, request_items=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.dynamodb.get_item.batch request_items=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="dynamodb",
        operation="batch_get_item",
        op_kwargs={
            "RequestItems": request_items,
            "ReturnConsumedCapacity": return_consumed_capacity,
        },
    )


async def transact(
    hub, ctx, transact_items: List, return_consumed_capacity: str = None
) -> Dict:
    r"""
    **Autogenerated function**

     TransactGetItems is a synchronous operation that atomically retrieves multiple items from one or more tables (but not from indexes) in a single account and Region. A TransactGetItems call can contain up to 25 TransactGetItem objects, each of which contains a Get structure that specifies an item to retrieve from a table in the account and Region. A call to TransactGetItems cannot retrieve items from tables in more than one AWS account or Region. The aggregate size of the items in the transaction cannot exceed 4 MB. DynamoDB rejects the entire TransactGetItems request if any of the following is true:   A conflicting operation is in the process of updating an item to be read.   There is insufficient provisioned capacity for the transaction to be completed.   There is a user error, such as an invalid data format.   The aggregate size of the items in the transaction cannot exceed 4 MB.

    Args:
        transact_items(List): An ordered array of up to 25 TransactGetItem objects, each of which contains a Get structure.
        return_consumed_capacity(str, optional): A value of TOTAL causes consumed capacity information to be returned, and a value of NONE prevents that information from being returned. No other value is valid. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.dynamodb.get_item.transact(ctx, transact_items=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.dynamodb.get_item.transact transact_items=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="dynamodb",
        operation="transact_get_items",
        op_kwargs={
            "TransactItems": transact_items,
            "ReturnConsumedCapacity": return_consumed_capacity,
        },
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""


async def disable(
    hub, ctx, gateway_id: str, route_table_id: str, dry_run: bool = None
) -> None:
    r"""
    **Autogenerated function**

    Disables a virtual private gateway (VGW) from propagating routes to a specified route table of a VPC.

    Args:
        gateway_id(str): The ID of the virtual private gateway.
        route_table_id(str): The ID of the route table.
        dry_run(bool, optional): Checks whether you have the required permissions for the action, without actually making the request, and provides an error response. If you have the required permissions, the error response is DryRunOperation. Otherwise, it is UnauthorizedOperation. Defaults to None.
    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.ec2.vgw_route_propagation.disable(
                ctx, gateway_id=value, route_table_id=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.ec2.vgw_route_propagation.disable gateway_id=value, route_table_id=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="ec2",
        operation="disable_vgw_route_propagation",
        op_kwargs={
            "GatewayId": gateway_id,
            "RouteTableId": route_table_id,
            "DryRun": dry_run,
        },
    )


async def enable(
    hub, ctx, gateway_id: str, route_table_id: str, dry_run: bool = None
) -> None:
    r"""
    **Autogenerated function**

    Enables a virtual private gateway (VGW) to propagate routes to the specified route table of a VPC.

    Args:
        gateway_id(str): The ID of the virtual private gateway that is attached to a VPC. The virtual private gateway must be attached to the same VPC that the routing tables are associated with. .
        route_table_id(str): The ID of the route table. The routing table must be associated with the same VPC that the virtual private gateway is attached to. .
        dry_run(bool, optional): Checks whether you have the required permissions for the action, without actually making the request, and provides an error response. If you have the required permissions, the error response is DryRunOperation. Otherwise, it is UnauthorizedOperation. Defaults to None.
    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.ec2.vgw_route_propagation.enable(
                ctx, gateway_id=value, route_table_id=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.ec2.vgw_route_propagation.enable gateway_id=value, route_table_id=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="ec2",
        operation="enable_vgw_route_propagation",
        op_kwargs={
            "GatewayId": gateway_id,
            "RouteTableId": route_table_id,
            "DryRun": dry_run,
        },
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict


async def list_all(hub, ctx, max_results: int = None, next_token: str = None) -> Dict:
    r"""
    **Autogenerated function**

    Returns a list of all invitations for the current AWS account. Applies only to Hyperledger Fabric.

    Args:
        max_results(int, optional): The maximum number of invitations to return. Defaults to None.
        next_token(str, optional): The pagination token that indicates the next set of results to retrieve. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.managedblockchain.invitation.list_all(ctx)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.managedblockchain.invitation.list_all
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="managedblockchain",
        operation="list_invitations",
        op_kwargs={"MaxResults": max_results, "NextToken": next_token},
    )


async def reject(hub, ctx, invitation_id: str) -> Dict:
    r"""
    **Autogenerated function**

    Rejects an invitation to join a network. This action can be called by a principal in an AWS account that has received an invitation to create a member and join a network. Applies only to Hyperledger Fabric.

    Args:
        invitation_id(str): The unique identifier of the invitation to reject.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.managedblockchain.invitation.reject(ctx, invitation_id=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.managedblockchain.invitation.reject invitation_id=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="managedblockchain",
        operation="reject_invitation",
        op_kwargs={"InvitationId": invitation_id},
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict


async def put(hub, ctx, schema_arn: str, document: str) -> Dict:
    r"""
    **Autogenerated function**

    Allows a schema to be updated using JSON upload. Only available for development schemas. See JSON Schema Format for more information.

    Args:
        schema_arn(str): The ARN of the schema to update.
        document(str): The replacement JSON schema.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.clouddirectory.schema.from_json.put(
                ctx, schema_arn=value, document=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.clouddirectory.schema.from_json.put schema_arn=value, document=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="clouddirectory",
        operation="put_schema_from_json",
        op_kwargs={"SchemaArn": schema_arn, "Document": document},
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict


async def create(
    hub, ctx, member_name: str, group_name: str, aws_account_id: str, namespace: str
) -> Dict:
    r"""
    **Autogenerated function**

    Adds an Amazon QuickSight user to an Amazon QuickSight group.

    Args:
        member_name(str): The name of the user that you want to add to the group membership.
        group_name(str): The name of the group that you want to add the user to.
        aws_account_id(str): The ID for the Amazon Web Services account; that the group is in. Currently, you use the ID for the Amazon Web Services account; that contains your Amazon QuickSight account.
        namespace(str): The namespace. Currently, you should set this to default.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.quicksight.group.membership.create(
                ctx, member_name=value, group_name=value, aws_account_id=value, namespace=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.quicksight.group.membership.create member_name=value, group_name=value, aws_account_id=value, namespace=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="quicksight",
        operation="create_group_membership",
        op_kwargs={
            "MemberName": member_name,
            "GroupName": group_name,
            "AwsAccountId": aws_account_id,
            "Namespace": namespace,
        },
    )


async def delete(
    hub, ctx, member_name: str, group_name: str, aws_account_id: str, namespace: str
) -> Dict:
    r"""
    **Autogenerated function**

    Removes a user from a group so that the user is no longer a member of the group.

    Args:
        member_name(str): The name of the user that you want to delete from the group membership.
        group_name(str): The name of the group that you want to delete the user from.
        aws_account_id(str): The ID for the Amazon Web Services account; that the group is in. Currently, you use the ID for the Amazon Web Services account; that contains your Amazon QuickSight account.
        namespace(str): The namespace. Currently, you should set this to default.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.quicksight.group.membership.delete(
                ctx, member_name=value, group_name=value, aws_account_id=value, namespace=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.quicksight.group.membership.delete member_name=value, group_name=value, aws_account_id=value, namespace=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="quicksight",
        operation="delete_group_membership",
        op_kwargs={
            "MemberName": member_name,
            "GroupName": group_name,
            "AwsAccountId": aws_account_id,
            "Namespace": namespace,
        },
    )


async def list_all(
    hub,
    ctx,
    group_name: str,
    aws_account_id: str,
    namespace: str,
    next_token: str = None,
    max_results: int = None,
) -> Dict:
    r"""
    **Autogenerated function**

    Lists member users in a group.

    Args:
        group_name(str): The name of the group that you want to see a membership list of.
        next_token(str, optional): A pagination token that can be used in a subsequent request. Defaults to None.
        max_results(int, optional): The maximum number of results to return from this request. Defaults to None.
        aws_account_id(str): The ID for the Amazon Web Services account; that the group is in. Currently, you use the ID for the Amazon Web Services account; that contains your Amazon QuickSight account.
        namespace(str): The namespace. Currently, you should set this to default.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.quicksight.group.membership.list_all(
                ctx, group_name=value, aws_account_id=value, namespace=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.quicksight.group.membership.list_all group_name=value, aws_account_id=value, namespace=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="quicksight",
        operation="list_group_memberships",
        op_kwargs={
            "GroupName": group_name,
            "NextToken": next_token,
            "MaxResults": max_results,
            "AwsAccountId": aws_account_id,
            "Namespace": namespace,
        },
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict
from typing import List


async def get(
    hub,
    ctx,
    instance_name: str,
    metric_name: str,
    period: int,
    start_time: str,
    end_time: str,
    unit: str,
    statistics: List,
) -> Dict:
    r"""
    **Autogenerated function**

    Returns the data points for the specified Amazon Lightsail instance metric, given an instance name. Metrics report the utilization of your resources, and the error counts generated by them. Monitor and collect metric data regularly to maintain the reliability, availability, and performance of your resources.

    Args:
        instance_name(str): The name of the instance for which you want to get metrics data.
        metric_name(str): The metric for which you want to return information. Valid instance metric names are listed below, along with the most useful statistics to include in your request, and the published unit value.     BurstCapacityPercentage  - The percentage of CPU performance available for your instance to burst above its baseline. Your instance continuously accrues and consumes burst capacity. Burst capacity stops accruing when your instance's BurstCapacityPercentage reaches 100%. For more information, see Viewing instance burst capacity in Amazon Lightsail.  Statistics: The most useful statistics are Maximum and Average.  Unit: The published unit is Percent.     BurstCapacityTime  - The available amount of time for your instance to burst at 100% CPU utilization. Your instance continuously accrues and consumes burst capacity. Burst capacity time stops accruing when your instance's BurstCapacityPercentage metric reaches 100%. Burst capacity time is consumed at the full rate only when your instance operates at 100% CPU utilization. For example, if your instance operates at 50% CPU utilization in the burstable zone for a 5-minute period, then it consumes CPU burst capacity minutes at a 50% rate in that period. Your instance consumed 2 minutes and 30 seconds of CPU burst capacity minutes in the 5-minute period. For more information, see Viewing instance burst capacity in Amazon Lightsail.  Statistics: The most useful statistics are Maximum and Average.  Unit: The published unit is Seconds.     CPUUtilization  - The percentage of allocated compute units that are currently in use on the instance. This metric identifies the processing power to run the applications on the instance. Tools in your operating system can show a lower percentage than Lightsail when the instance is not allocated a full processor core.  Statistics: The most useful statistics are Maximum and Average.  Unit: The published unit is Percent.     NetworkIn  - The number of bytes received on all network interfaces by the instance. This metric identifies the volume of incoming network traffic to the instance. The number reported is the number of bytes received during the period. Because this metric is reported in 5-minute intervals, divide the reported number by 300 to find Bytes/second.  Statistics: The most useful statistic is Sum.  Unit: The published unit is Bytes.     NetworkOut  - The number of bytes sent out on all network interfaces by the instance. This metric identifies the volume of outgoing network traffic from the instance. The number reported is the number of bytes sent during the period. Because this metric is reported in 5-minute intervals, divide the reported number by 300 to find Bytes/second.  Statistics: The most useful statistic is Sum.  Unit: The published unit is Bytes.     StatusCheckFailed  - Reports whether the instance passed or failed both the instance status check and the system status check. This metric can be either 0 (passed) or 1 (failed). This metric data is available in 1-minute (60 seconds) granularity.  Statistics: The most useful statistic is Sum.  Unit: The published unit is Count.     StatusCheckFailed_Instance  - Reports whether the instance passed or failed the instance status check. This metric can be either 0 (passed) or 1 (failed). This metric data is available in 1-minute (60 seconds) granularity.  Statistics: The most useful statistic is Sum.  Unit: The published unit is Count.     StatusCheckFailed_System  - Reports whether the instance passed or failed the system status check. This metric can be either 0 (passed) or 1 (failed). This metric data is available in 1-minute (60 seconds) granularity.  Statistics: The most useful statistic is Sum.  Unit: The published unit is Count.  .
        period(int): The granularity, in seconds, of the returned data points. The StatusCheckFailed, StatusCheckFailed_Instance, and StatusCheckFailed_System instance metric data is available in 1-minute (60 seconds) granularity. All other instance metric data is available in 5-minute (300 seconds) granularity.
        start_time(str): The start time of the time period.
        end_time(str): The end time of the time period.
        unit(str): The unit for the metric data request. Valid units depend on the metric data being requested. For the valid units to specify with each available metric, see the metricName parameter.
        statistics(List): The statistic for the metric. The following statistics are available:    Minimum - The lowest value observed during the specified period. Use this value to determine low volumes of activity for your application.    Maximum - The highest value observed during the specified period. Use this value to determine high volumes of activity for your application.    Sum - All values submitted for the matching metric added together. You can use this statistic to determine the total volume of a metric.    Average - The value of Sum / SampleCount during the specified period. By comparing this statistic with the Minimum and Maximum values, you can determine the full scope of a metric and how close the average use is to the Minimum and Maximum values. This comparison helps you to know when to increase or decrease your resources.    SampleCount - The count, or number, of data points used for the statistical calculation.  .

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.lightsail.instance.metric_data.get(
                ctx,
                instance_name=value,
                metric_name=value,
                period=value,
                start_time=value,
                end_time=value,
                unit=value,
                statistics=value,
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.lightsail.instance.metric_data.get instance_name=value, metric_name=value, period=value, start_time=value, end_time=value, unit=value, statistics=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="lightsail",
        operation="get_instance_metric_data",
        op_kwargs={
            "instanceName": instance_name,
            "metricName": metric_name,
            "period": period,
            "startTime": start_time,
            "endTime": end_time,
            "unit": unit,
            "statistics": statistics,
        },
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""


async def subscribe(hub, ctx, resource_arn: str, event: str, topic_arn: str) -> None:
    r"""
    **Autogenerated function**

    Enables the process of sending Amazon Simple Notification Service (SNS) notifications about a specified event to a specified SNS topic.

    Args:
        resource_arn(str): The ARN of the assessment template that is used during the event for which you want to receive SNS notifications.
        event(str): The event for which you want to receive SNS notifications.
        topic_arn(str): The ARN of the SNS topic to which the SNS notifications are sent.
    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.inspector.to_event.subscribe(
                ctx, resource_arn=value, event=value, topic_arn=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.inspector.to_event.subscribe resource_arn=value, event=value, topic_arn=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="inspector",
        operation="subscribe_to_event",
        op_kwargs={"resourceArn": resource_arn, "event": event, "topicArn": topic_arn},
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict


async def get(hub, ctx, python_script: str = None) -> Dict:
    r"""
    **Autogenerated function**

    Transforms a Python script into a directed acyclic graph (DAG).

    Args:
        python_script(str, optional): The Python script to transform. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.glue.dataflow_graph.get(ctx)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.glue.dataflow_graph.get
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="glue",
        operation="get_dataflow_graph",
        op_kwargs={"PythonScript": python_script},
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict


async def cancel(hub, ctx, service_name: str) -> Dict:
    r"""
    **Autogenerated function**

    Attempts to cancel a service pipeline deployment on an UpdateServicePipeline action, if the deployment is IN_PROGRESS. For more information, see Update a service pipeline in the AWS Proton Administrator guide or the AWS Proton User guide. The following list includes potential cancellation scenarios.   If the cancellation attempt succeeds, the resulting deployment state is CANCELLED.   If the cancellation attempt fails, the resulting deployment state is FAILED.   If the current UpdateServicePipeline action succeeds before the cancellation attempt starts, the resulting deployment state is SUCCEEDED and the cancellation attempt has no effect.

    Args:
        service_name(str): The name of the service with the service pipeline deployment to cancel.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.proton.service.pipeline.deployment.cancel(
                ctx, service_name=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.proton.service.pipeline.deployment.cancel service_name=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="proton",
        operation="cancel_service_pipeline_deployment",
        op_kwargs={"serviceName": service_name},
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""


async def update(
    hub, ctx, name: str, hierarchy_group_id: str, instance_id: str
) -> None:
    r"""
    **Autogenerated function**

    Updates the name of the user hierarchy group.

    Args:
        name(str): The name of the hierarchy group. Must not be more than 100 characters.
        hierarchy_group_id(str): The identifier of the hierarchy group.
        instance_id(str): The identifier of the Amazon Connect instance. You can find the instanceId in the ARN of the instance.
    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.connect.user.hierarchy.group.name.update(
                ctx, name=value, hierarchy_group_id=value, instance_id=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.connect.user.hierarchy.group.name.update name=value, hierarchy_group_id=value, instance_id=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="connect",
        operation="update_user_hierarchy_group_name",
        op_kwargs={
            "Name": name,
            "HierarchyGroupId": hierarchy_group_id,
            "InstanceId": instance_id,
        },
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict
from typing import List


async def create(
    hub,
    ctx,
    name: str,
    id_: str,
    description: str = None,
    client_request_token: str = None,
    source_code: List = None,
    toolchain: Dict = None,
    tags: Dict = None,
) -> Dict:
    r"""
    **Autogenerated function**

    Creates a project, including project resources. This action creates a project based on a submitted project request. A set of source code files and a toolchain template file can be included with the project request. If these are not provided, an empty project is created.

    Args:
        name(str): The display name for the project to be created in AWS CodeStar.
        id_(str): The ID of the project to be created in AWS CodeStar.
        description(str, optional): The description of the project, if any. Defaults to None.
        client_request_token(str, optional): A user- or system-generated token that identifies the entity that requested project creation. This token can be used to repeat the request. Defaults to None.
        source_code(List, optional): A list of the Code objects submitted with the project request. If this parameter is specified, the request must also include the toolchain parameter. Defaults to None.
        toolchain(Dict, optional): The name of the toolchain template file submitted with the project request. If this parameter is specified, the request must also include the sourceCode parameter. Defaults to None.
        tags(Dict, optional): The tags created for the project. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.codestar.project.create(ctx, name=value, id_=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.codestar.project.create name=value, id_=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="codestar",
        operation="create_project",
        op_kwargs={
            "name": name,
            "id": id_,
            "description": description,
            "clientRequestToken": client_request_token,
            "sourceCode": source_code,
            "toolchain": toolchain,
            "tags": tags,
        },
    )


async def delete(
    hub, ctx, id_: str, client_request_token: str = None, delete_stack: bool = None
) -> Dict:
    r"""
    **Autogenerated function**

    Deletes a project, including project resources. Does not delete users associated with the project, but does delete the IAM roles that allowed access to the project.

    Args:
        id_(str): The ID of the project to be deleted in AWS CodeStar.
        client_request_token(str, optional): A user- or system-generated token that identifies the entity that requested project deletion. This token can be used to repeat the request. . Defaults to None.
        delete_stack(bool, optional): Whether to send a delete request for the primary stack in AWS CloudFormation originally used to generate the project and its resources. This option will delete all AWS resources for the project (except for any buckets in Amazon S3) as well as deleting the project itself. Recommended for most use cases. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.codestar.project.delete(ctx, id_=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.codestar.project.delete id_=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="codestar",
        operation="delete_project",
        op_kwargs={
            "id": id_,
            "clientRequestToken": client_request_token,
            "deleteStack": delete_stack,
        },
    )


async def describe(hub, ctx, id_: str) -> Dict:
    r"""
    **Autogenerated function**

    Describes a project and its resources.

    Args:
        id_(str): The ID of the project.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.codestar.project.describe(ctx, id_=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.codestar.project.describe id_=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="codestar",
        operation="describe_project",
        op_kwargs={"id": id_},
    )


async def list_all(hub, ctx, next_token: str = None, max_results: int = None) -> Dict:
    r"""
    **Autogenerated function**

    Lists all projects in AWS CodeStar associated with your AWS account.

    Args:
        next_token(str, optional): The continuation token to be used to return the next set of results, if the results cannot be returned in one response. Defaults to None.
        max_results(int, optional): The maximum amount of data that can be contained in a single set of results. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.codestar.project.list_all(ctx)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.codestar.project.list_all
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="codestar",
        operation="list_projects",
        op_kwargs={"nextToken": next_token, "maxResults": max_results},
    )


async def tag(hub, ctx, id_: str, tags: Dict) -> Dict:
    r"""
    **Autogenerated function**

    Adds tags to a project.

    Args:
        id_(str): The ID of the project you want to add a tag to.
        tags(Dict): The tags you want to add to the project.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.codestar.project.tag(ctx, id_=value, tags=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.codestar.project.tag id_=value, tags=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="codestar",
        operation="tag_project",
        op_kwargs={"id": id_, "tags": tags},
    )


async def untag(hub, ctx, id_: str, tags: List) -> Dict:
    r"""
    **Autogenerated function**

    Removes tags from a project.

    Args:
        id_(str): The ID of the project to remove tags from.
        tags(List): The tags to remove from the project.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.codestar.project.untag(ctx, id_=value, tags=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.codestar.project.untag id_=value, tags=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="codestar",
        operation="untag_project",
        op_kwargs={"id": id_, "tags": tags},
    )


async def update(hub, ctx, id_: str, name: str = None, description: str = None) -> Dict:
    r"""
    **Autogenerated function**

    Updates a project in AWS CodeStar.

    Args:
        id_(str): The ID of the project you want to update.
        name(str, optional): The name of the project you want to update. Defaults to None.
        description(str, optional): The description of the project, if any. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.codestar.project.update(ctx, id_=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.codestar.project.update id_=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="codestar",
        operation="update_project",
        op_kwargs={"id": id_, "name": name, "description": description},
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict


async def describe_all(hub, ctx, language: str) -> Dict:
    r"""
    **Autogenerated function**

    Returns information about all available AWS Trusted Advisor checks, including the name, ID, category, description, and metadata. You must specify a language code. The AWS Support API currently supports English ("en") and Japanese ("ja"). The response contains a TrustedAdvisorCheckDescription object for each check. You must set the AWS Region to us-east-1.    You must have a Business or Enterprise Support plan to use the AWS Support API.    If you call the AWS Support API from an account that does not have a Business or Enterprise Support plan, the SubscriptionRequiredException error message appears. For information about changing your support plan, see AWS Support.   The names and descriptions for Trusted Advisor checks are subject to change. We recommend that you specify the check ID in your code to uniquely identify a check.

    Args:
        language(str): The ISO 639-1 code for the language in which AWS provides support. AWS Support currently supports English ("en") and Japanese ("ja"). Language parameters must be passed explicitly for operations that take them.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.support.trusted_advisor_check.init.describe_all(
                ctx, language=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.support.trusted_advisor_check.init.describe_all language=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="support",
        operation="describe_trusted_advisor_checks",
        op_kwargs={"language": language},
    )


async def refresh(hub, ctx, check_id: str) -> Dict:
    r"""
    **Autogenerated function**

    Refreshes the AWS Trusted Advisor check that you specify using the check ID. You can get the check IDs by calling the DescribeTrustedAdvisorChecks operation.  Some checks are refreshed automatically. If you call the RefreshTrustedAdvisorCheck operation to refresh them, you might see the InvalidParameterValue error.  The response contains a TrustedAdvisorCheckRefreshStatus object.    You must have a Business or Enterprise Support plan to use the AWS Support API.    If you call the AWS Support API from an account that does not have a Business or Enterprise Support plan, the SubscriptionRequiredException error message appears. For information about changing your support plan, see AWS Support.

    Args:
        check_id(str): The unique identifier for the Trusted Advisor check to refresh.  Specifying the check ID of a check that is automatically refreshed causes an InvalidParameterValue error. .

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.support.trusted_advisor_check.init.refresh(ctx, check_id=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.support.trusted_advisor_check.init.refresh check_id=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="support",
        operation="refresh_trusted_advisor_check",
        op_kwargs={"checkId": check_id},
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict


__func_alias__ = {"list_": "list"}


async def list_(
    hub, ctx, ledger_name: str, max_results: int = None, next_token: str = None
) -> Dict:
    r"""
    **Autogenerated function**

    Returns an array of all Amazon QLDB journal stream descriptors for a given ledger. The output of each stream descriptor includes the same details that are returned by DescribeJournalKinesisStream. This action does not return any expired journal streams. For more information, see Expiration for terminal streams in the Amazon QLDB Developer Guide. This action returns a maximum of MaxResults items. It is paginated so that you can retrieve all the items by calling ListJournalKinesisStreamsForLedger multiple times.

    Args:
        ledger_name(str): The name of the ledger.
        max_results(int, optional): The maximum number of results to return in a single ListJournalKinesisStreamsForLedger request. (The actual number of results returned might be fewer.). Defaults to None.
        next_token(str, optional): A pagination token, indicating that you want to retrieve the next page of results. If you received a value for NextToken in the response from a previous ListJournalKinesisStreamsForLedger call, you should use that value as input here. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.qldb.journal.kinesis_stream.for_ledger.list(
                ctx, ledger_name=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.qldb.journal.kinesis_stream.for_ledger.list ledger_name=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="qldb",
        operation="list_journal_kinesis_streams_for_ledger",
        op_kwargs={
            "LedgerName": ledger_name,
            "MaxResults": max_results,
            "NextToken": next_token,
        },
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict


__func_alias__ = {"set_": "set"}


async def set_(hub, ctx, identity: str, forwarding_enabled: bool) -> Dict:
    r"""
    **Autogenerated function**

    Given an identity (an email address or a domain), enables or disables whether Amazon SES forwards bounce and complaint notifications as email. Feedback forwarding can only be disabled when Amazon Simple Notification Service (Amazon SNS) topics are specified for both bounces and complaints.  Feedback forwarding does not apply to delivery notifications. Delivery notifications are only available through Amazon SNS.  You can execute this operation no more than once per second. For more information about using notifications with Amazon SES, see the Amazon SES Developer Guide.

    Args:
        identity(str): The identity for which to set bounce and complaint notification forwarding. Examples: user@example.com, example.com.
        forwarding_enabled(bool): Sets whether Amazon SES will forward bounce and complaint notifications as email. true specifies that Amazon SES will forward bounce and complaint notifications as email, in addition to any Amazon SNS topic publishing otherwise specified. false specifies that Amazon SES will publish bounce and complaint notifications only through Amazon SNS. This value can only be set to false when Amazon SNS topics are set for both Bounce and Complaint notification types.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.ses.identity.feedback_forwarding_enabled.set(
                ctx, identity=value, forwarding_enabled=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.ses.identity.feedback_forwarding_enabled.set identity=value, forwarding_enabled=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="ses",
        operation="set_identity_feedback_forwarding_enabled",
        op_kwargs={"Identity": identity, "ForwardingEnabled": forwarding_enabled},
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict


async def disable(hub, ctx) -> Dict:
    r"""
    **Autogenerated function**

    Disables Security Hub in your account only in the current Region. To disable Security Hub in all Regions, you must submit one request per Region where you have enabled Security Hub. When you disable Security Hub for an administrator account, it doesn't disable Security Hub for any associated member accounts. When you disable Security Hub, your existing findings and insights and any Security Hub configuration settings are deleted after 90 days and cannot be recovered. Any standards that were enabled are disabled, and your administrator and member account associations are removed. If you want to save your existing findings, you must export them before you disable Security Hub.


    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.securityhub.security_hub.init.disable(ctx)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.securityhub.security_hub.init.disable
    """
    return await hub.tool.aws.client.exec(
        ctx, service_name="securityhub", operation="disable_security_hub", op_kwargs={}
    )


async def enable(
    hub, ctx, tags: Dict = None, enable_default_standards: bool = None
) -> Dict:
    r"""
    **Autogenerated function**

    Enables Security Hub for your account in the current Region or the Region you specify in the request. When you enable Security Hub, you grant to Security Hub the permissions necessary to gather findings from other services that are integrated with Security Hub. When you use the EnableSecurityHub operation to enable Security Hub, you also automatically enable the following standards.   CIS Amazon Web Services Foundations   Amazon Web Services Foundational Security Best Practices   You do not enable the Payment Card Industry Data Security Standard (PCI DSS) standard.  To not enable the automatically enabled standards, set EnableDefaultStandards to false. After you enable Security Hub, to enable a standard, use the BatchEnableStandards operation. To disable a standard, use the BatchDisableStandards operation. To learn more, see the setup information in the Security Hub User Guide.

    Args:
        tags(Dict, optional): The tags to add to the hub resource when you enable Security Hub. Defaults to None.
        enable_default_standards(bool, optional): Whether to enable the security standards that Security Hub has designated as automatically enabled. If you do not provide a value for EnableDefaultStandards, it is set to true. To not enable the automatically enabled standards, set EnableDefaultStandards to false. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.securityhub.security_hub.init.enable(ctx)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.securityhub.security_hub.init.enable
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="securityhub",
        operation="enable_security_hub",
        op_kwargs={"Tags": tags, "EnableDefaultStandards": enable_default_standards},
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict
from typing import List


async def create(hub, ctx, directory_id: str, name: str = None) -> Dict:
    r"""
    **Autogenerated function**

    Creates a snapshot of a Simple AD or Microsoft AD directory in the AWS cloud.  You cannot take snapshots of AD Connector directories.

    Args:
        directory_id(str): The identifier of the directory of which to take a snapshot.
        name(str, optional): The descriptive name to apply to the snapshot. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.ds.snapshot.init.create(ctx, directory_id=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.ds.snapshot.init.create directory_id=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="ds",
        operation="create_snapshot",
        op_kwargs={"DirectoryId": directory_id, "Name": name},
    )


async def delete(hub, ctx, snapshot_id: str) -> Dict:
    r"""
    **Autogenerated function**

    Deletes a directory snapshot.

    Args:
        snapshot_id(str): The identifier of the directory snapshot to be deleted.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.ds.snapshot.init.delete(ctx, snapshot_id=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.ds.snapshot.init.delete snapshot_id=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="ds",
        operation="delete_snapshot",
        op_kwargs={"SnapshotId": snapshot_id},
    )


async def describe_all(
    hub,
    ctx,
    directory_id: str = None,
    snapshot_ids: List = None,
    next_token: str = None,
    limit: int = None,
) -> Dict:
    r"""
    **Autogenerated function**

    Obtains information about the directory snapshots that belong to this account. This operation supports pagination with the use of the NextToken request and response parameters. If more results are available, the DescribeSnapshots.NextToken member contains a token that you pass in the next call to DescribeSnapshots to retrieve the next set of items. You can also specify a maximum number of return results with the Limit parameter.

    Args:
        directory_id(str, optional): The identifier of the directory for which to retrieve snapshot information. Defaults to None.
        snapshot_ids(List, optional): A list of identifiers of the snapshots to obtain the information for. If this member is null or empty, all snapshots are returned using the Limit and NextToken members. Defaults to None.
        next_token(str, optional): The DescribeSnapshotsResult.NextToken value from a previous call to DescribeSnapshots. Pass null if this is the first call. Defaults to None.
        limit(int, optional): The maximum number of objects to return. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.ds.snapshot.init.describe_all(ctx)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.ds.snapshot.init.describe_all
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="ds",
        operation="describe_snapshots",
        op_kwargs={
            "DirectoryId": directory_id,
            "SnapshotIds": snapshot_ids,
            "NextToken": next_token,
            "Limit": limit,
        },
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict


async def get(hub, ctx, license_arn: str) -> Dict:
    r"""
    **Autogenerated function**

    Gets detailed information about the usage of the specified license.

    Args:
        license_arn(str): Amazon Resource Name (ARN) of the license.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.license_manager.license_.usage.get(ctx, license_arn=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.license_manager.license_.usage.get license_arn=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="license-manager",
        operation="get_license_usage",
        op_kwargs={"LicenseArn": license_arn},
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict


async def describe_all(hub, ctx) -> Dict:
    r"""
    **Autogenerated function**

    Provides information about the number and type of attacks Shield has detected in the last year for all resources that belong to your account, regardless of whether you've defined Shield protections for them. This operation is available to Shield customers as well as to Shield Advanced customers. The operation returns data for the time range of midnight UTC, one year ago, to midnight UTC, today. For example, if the current time is 2020-10-26 15:39:32 PDT, equal to 2020-10-26 22:39:32 UTC, then the time range for the attack data returned is from 2019-10-26 00:00:00 UTC to 2020-10-26 00:00:00 UTC.  The time range indicates the period covered by the attack statistics data items.


    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.shield.attack.statistic.describe_all(ctx)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.shield.attack.statistic.describe_all
    """
    return await hub.tool.aws.client.exec(
        ctx, service_name="shield", operation="describe_attack_statistics", op_kwargs={}
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict


async def describe_all(
    hub, ctx, flow_name: str, max_results: int = None, next_token: str = None
) -> Dict:
    r"""
    **Autogenerated function**

     Fetches the execution history of the flow.

    Args:
        flow_name(str):  The specified name of the flow. Spaces are not allowed. Use underscores (_) or hyphens (-) only. .
        max_results(int, optional):  Specifies the maximum number of items that should be returned in the result set. The default for maxResults is 20 (for all paginated API operations). . Defaults to None.
        next_token(str, optional):  The pagination token for the next page of data. . Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.appflow.flow.execution_record.describe_all(ctx, flow_name=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.appflow.flow.execution_record.describe_all flow_name=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="appflow",
        operation="describe_flow_execution_records",
        op_kwargs={
            "flowName": flow_name,
            "maxResults": max_results,
            "nextToken": next_token,
        },
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict


async def update(hub, ctx, id_: str, comment: str = None) -> Dict:
    r"""
    **Autogenerated function**

    Updates the comment for a specified hosted zone.

    Args:
        id_(str): The ID for the hosted zone that you want to update the comment for.
        comment(str, optional): The new comment for the hosted zone. If you don't specify a value for Comment, Amazon Route 53 deletes the existing value of the Comment element, if any. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.route53.hosted_zone.comment.update(ctx, id_=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.route53.hosted_zone.comment.update id_=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="route53",
        operation="update_hosted_zone_comment",
        op_kwargs={"Id": id_, "Comment": comment},
    )
